################################## Paleoecological groups (palynology) ################################################################


library(cluster)
library(rioja)
library(CommEcol)

# Load data
paly = read.csv("pollen_counts.csv",check.names = F)
paly[is.na(paly)] <- 0

library(readxl)

afi <- read_excel("File.xlsx", sheet = "Sheet1")
table(afi$Categoria)

# take out RW taxa
pol <- paly[,-1][,afi$Categoria != "rw"]

# take out samples with 80 grains or less

con <- rowSums(pol) > 80 
framePol <- pol[con,]

meter <- paly[con,1] # depth

rownames(framePol) <- meter


# Distance matrix CHAO / SORENSEN
chaod <- dis.chao(framePol, index='sorensen') # CDI among all samples

# image


mchaod <- as.matrix(chaod)
image(mchaod,xaxt="n",yaxt="n", col= clrs(50) )
axis(side=1, at= seq(0,1,length.out=43), labels=colnames(mchaod), cex.axis= 0.5,las=2) 
axis(side=2, at= seq(0,1,length.out=43), labels=colnames(mchaod), cex.axis= 0.5,las=2) 




################################## Occurences ################################################################

library(BIEN)

## Download occurences for each group or genera



Aguiaria<-BIEN_occurrence_genus("Aguiaria",only.new.world=TRUE)
Alchornea<-BIEN_occurrence_genus("Alchornea",only.new.world=TRUE)
Amanoa<-BIEN_occurrence_genus("Amanoa",only.new.world=TRUE)
Anemia<-BIEN_occurrence_genus("Anemia",only.new.world=TRUE)
Araucaria<-BIEN_occurrence_genus("Araucaria",only.new.world=TRUE)
Catostemma<-BIEN_occurrence_genus("Catostemma",only.new.world=TRUE)
Chrysophyllum<-BIEN_occurrence_genus("Chrysophyllum",only.new.world=TRUE)
Cremastosperma<-BIEN_occurrence_genus("Cremastosperma",only.new.world=TRUE)
Dalechampia<-BIEN_occurrence_genus("Dalechampia",only.new.world=TRUE)
Iriartea<-BIEN_occurrence_genus("Iriartea",only.new.world=TRUE)
Ludwigia<-BIEN_occurrence_genus("Ludwigia",only.new.world=TRUE)
Malmea<-BIEN_occurrence_genus("Malmea",only.new.world=TRUE)
Mauritia<-BIEN_occurrence_genus("Mauritia",only.new.world=TRUE)
Merremia<-BIEN_occurrence_genus("Merremia",only.new.world=TRUE)
Micropholis<-BIEN_occurrence_genus("Micropholis",only.new.world=TRUE)
Pelliciera<-BIEN_occurrence_genus("Pelliciera",only.new.world=TRUE)
Phytelephas<-BIEN_occurrence_genus("Phytelephas",only.new.world=TRUE)
Podocarpus<-BIEN_occurrence_genus("Podocarpus",only.new.world=TRUE)
Polypodium<-BIEN_occurrence_genus("Polypodium",only.new.world=TRUE)
Quararibea<-BIEN_occurrence_genus("Quararibea",only.new.world=TRUE)
Sapium<-BIEN_occurrence_genus("Sapium",only.new.world=TRUE)



## lats 


Aguiarialats<-Aguiaria$latitude
Alchornealats<-Alchornea$latitude
Amanoalats<-Amanoa$latitude
Anemialats<-Anemia$latitude
Araucarialats<-Araucaria$latitude
Catostemmalats<-Catostemma$latitude
Chrysophyllumlats<-Chrysophyllum$latitude
Cremastospermalats<-Cremastosperma$latitude
Dalechampialats<-Dalechampia$latitude
Iriartealats<-Iriartea$latitude
Ludwigialats<-Ludwigia$latitude
Malmealats<-Malmea$latitude
Mauritialats<-Mauritia$latitude
Merremialats<-Merremia$latitude
Micropholislats<-Micropholis$latitude
Pellicieralats<-Pelliciera$latitude
Phytelephaslats<-Phytelephas$latitude
Podocarpuslats<-Podocarpus$latitude
Polypodiumlats<-Polypodium$latitude
Quararibealats<-Quararibea$latitude
Sapiumlats<-Sapium$latitude

## lons 


Aguiarialons<-Aguiaria$longitude
Alchornealons<-Alchornea$longitude
Amanoalons<-Amanoa$longitude
Anemialons<-Anemia$longitude
Araucarialons<-Araucaria$longitude
Catostemmalons<-Catostemma$longitude
Chrysophyllumlons<-Chrysophyllum$longitude
Cremastospermalons<-Cremastosperma$longitude
Dalechampialons<-Dalechampia$longitude
Iriartealons<-Iriartea$longitude
Ludwigialons<-Ludwigia$longitude
Malmealons<-Malmea$longitude
Mauritialons<-Mauritia$longitude
Merremialons<-Merremia$longitude
Micropholislons<-Micropholis$longitude
Pellicieralons<-Pelliciera$longitude
Phytelephaslons<-Phytelephas$longitude
Podocarpuslons<-Podocarpus$longitude
Polypodiumlons<-Polypodium$longitude
Quararibealons<-Quararibea$longitude
Sapiumlons<-Sapium$longitude


##coords <- data.frame(x=lons,y=lats)


dfAguiaria<-na.omit(data.frame(x=Aguiarialons,y=Aguiarialats))
dfAlchornea<-na.omit(data.frame(x=Alchornealons,y=Alchornealats))
dfAmanoa<-na.omit(data.frame(x=Amanoalons,y=Amanoalats))
dfAnemia<-na.omit(data.frame(x=Anemialons,y=Anemialats))
dfAraucaria<-na.omit(data.frame(x=Araucarialons,y=Araucarialats))
dfCatostemma<-na.omit(data.frame(x=Catostemmalons,y=Catostemmalats))
dfChrysophyllum<-na.omit(data.frame(x=Chrysophyllumlons,y=Chrysophyllumlats))
dfCremastosperma<-na.omit(data.frame(x=Cremastospermalons,y=Cremastospermalats))
dfDalechampia<-na.omit(data.frame(x=Dalechampialons,y=Dalechampialats))
dfIriartea<-na.omit(data.frame(x=Iriartealons,y=Iriartealats))
dfLudwigia<-na.omit(data.frame(x=Ludwigialons,y=Ludwigialats))
dfMalmea<-na.omit(data.frame(x=Malmealons,y=Malmealats))
dfMauritia<-na.omit(data.frame(x=Mauritialons,y=Mauritialats))
dfMerremia<-na.omit(data.frame(x=Merremialons,y=Merremialats))
dfMicropholis<-na.omit(data.frame(x=Micropholislons,y=Micropholislats))
dfPelliciera<-na.omit(data.frame(x=Pellicieralons,y=Pellicieralats))
dfPhytelephas<-na.omit(data.frame(x=Phytelephaslons,y=Phytelephaslats))
dfPodocarpus<-na.omit(data.frame(x=Podocarpuslons,y=Podocarpuslats))
dfPolypodium<-na.omit(data.frame(x=Polypodiumlons,y=Polypodiumlats))
dfQuararibea<-na.omit(data.frame(x=Quararibealons,y=Quararibealats))
dfSapium<-na.omit(data.frame(x=Sapiumlons,y=Sapiumlats))




write.csv(dfAguiaria,file="dfAguiaria.csv")
write.csv(dfAlchornea,file="dfAlchornea.csv")
write.csv(dfAmanoa,file="dfAmanoa.csv")
write.csv(dfAnemia,file="dfAnemia.csv")
write.csv(dfAraucaria,file="dfAraucaria.csv")
write.csv(dfCatostemma,file="dfCatostemma.csv")
write.csv(dfChrysophyllum,file="dfChrysophyllum.csv")
write.csv(dfCremastosperma,file="dfCremastosperma.csv")
write.csv(dfDalechampia,file="dfDalechampia.csv")
write.csv(dfIriartea,file="dfIriartea.csv")
write.csv(dfLudwigia,file="dfLudwigia.csv")
write.csv(dfMalmea,file="dfMalmea.csv")
write.csv(dfMauritia,file="dfMauritia.csv")
write.csv(dfMerremia,file="dfMerremia.csv")
write.csv(dfMicropholis,file="dfMicropholis.csv")
write.csv(dfPelliciera,file="dfPelliciera.csv")
write.csv(dfPhytelephas,file="dfPhytelephas.csv")
write.csv(dfPodocarpus,file="dfPodocarpus.csv")
write.csv(dfPolypodium,file="dfPolypodium.csv")
write.csv(dfQuararibea,file="dfQuararibea.csv")
write.csv(dfSapium,file="dfSapium.csv")



## Bombacoideae




Bernoullia<-BIEN_occurrence_genus("Bernoullia",only.new.world=TRUE)
Gyranthera<-BIEN_occurrence_genus("Gyranthera",only.new.world=TRUE)
Huberodendron<-BIEN_occurrence_genus("Huberodendron",only.new.world=TRUE)
Adansonia<-BIEN_occurrence_genus("Adansonia",only.new.world=TRUE)
Cavanillesia<-BIEN_occurrence_genus("Cavanillesia",only.new.world=TRUE)
Aguiaria<-BIEN_occurrence_genus("Aguiaria",only.new.world=TRUE)
Scleronema<-BIEN_occurrence_genus("Scleronema",only.new.world=TRUE)
Catostema<-BIEN_occurrence_genus("Catostema",only.new.world=TRUE)
Rhodognaphalon<-BIEN_occurrence_genus("Rhodognaphalon",only.new.world=TRUE)
Bombacopsis<-BIEN_occurrence_genus("Bombacopsis",only.new.world=TRUE)
Bombax<-BIEN_occurrence_genus("Bombax",only.new.world=TRUE)
Chorisia<-BIEN_occurrence_genus("Chorisia",only.new.world=TRUE)
Ceiba<-BIEN_occurrence_genus("Ceiba",only.new.world=TRUE)
Eriotheca<-BIEN_occurrence_genus("Eriotheca",only.new.world=TRUE)
Neobuchia<-BIEN_occurrence_genus("Neobuchia",only.new.world=TRUE)
Pachira<-BIEN_occurrence_genus("Pachira",only.new.world=TRUE)
Pochota<-BIEN_occurrence_genus("Pochota",only.new.world=TRUE)
Pseudobombax<-BIEN_occurrence_genus("Pseudobombax",only.new.world=TRUE)
Spirotheca<-BIEN_occurrence_genus("Spirotheca",only.new.world=TRUE)


##lats


Bernoullialats<-Bernoullia$latitude
Gyrantheralats<-Gyranthera$latitude
Huberodendronlats<-Huberodendron$latitude
Adansonialats<-Adansonia$latitude
Cavanillesialats<-Cavanillesia$latitude
Aguiarialats<-Aguiaria$latitude
Scleronemalats<-Scleronema$latitude
Catostemalats<-Catostema$latitude
Rhodognaphalonlats<-Rhodognaphalon$latitude
Bombacopsislats<-Bombacopsis$latitude
Bombaxlats<-Bombax$latitude
Chorisialats<-Chorisia$latitude
Ceibalats<-Ceiba$latitude
Eriothecalats<-Eriotheca$latitude
Neobuchialats<-Neobuchia$latitude
Pachiralats<-Pachira$latitude
Pochotalats<-Pochota$latitude
Pseudobombaxlats<-Pseudobombax$latitude
Spirothecalats<-Spirotheca$latitude



##lons



Bernoullialons<-Bernoullia$longitude
Gyrantheralons<-Gyranthera$longitude
Huberodendronlons<-Huberodendron$longitude
Adansonialons<-Adansonia$longitude
Cavanillesialons<-Cavanillesia$longitude
Aguiarialons<-Aguiaria$longitude
Scleronemalons<-Scleronema$longitude
Catostemalons<-Catostema$longitude
Rhodognaphalonlons<-Rhodognaphalon$longitude
Bombacopsislons<-Bombacopsis$longitude
Bombaxlons<-Bombax$longitude
Chorisialons<-Chorisia$longitude
Ceibalons<-Ceiba$longitude
Eriothecalons<-Eriotheca$longitude
Neobuchialons<-Neobuchia$longitude
Pachiralons<-Pachira$longitude
Pochotalons<-Pochota$longitude
Pseudobombaxlons<-Pseudobombax$longitude
Spirothecalons<-Spirotheca$longitude



Bernoulliacoords<-data.frame(x=Bernoullialons,y=Bernoullialats)
Gyrantheracoords<-data.frame(x=Gyrantheralons,y=Gyrantheralats)
Huberodendroncoords<-data.frame(x=Huberodendronlons,y=Huberodendronlats)
Adansoniacoords<-data.frame(x=Adansonialons,y=Adansonialats)
Cavanillesiacoords<-data.frame(x=Cavanillesialons,y=Cavanillesialats)
Aguiariacoords<-data.frame(x=Aguiarialons,y=Aguiarialats)
Scleronemacoords<-data.frame(x=Scleronemalons,y=Scleronemalats)
Catostemacoords<-data.frame(x=Catostemalons,y=Catostemalats)
Rhodognaphaloncoords<-data.frame(x=Rhodognaphalonlons,y=Rhodognaphalonlats)
Bombacopsiscoords<-data.frame(x=Bombacopsislons,y=Bombacopsislats)
Bombaxcoords<-data.frame(x=Bombaxlons,y=Bombaxlats)
Chorisiacoords<-data.frame(x=Chorisialons,y=Chorisialats)
Ceibacoords<-data.frame(x=Ceibalons,y=Ceibalats)
Eriothecacoords<-data.frame(x=Eriothecalons,y=Eriothecalats)
Neobuchiacoords<-data.frame(x=Neobuchialons,y=Neobuchialats)
Pachiracoords<-data.frame(x=Pachiralons,y=Pachiralats)
Pochotacoords<-data.frame(x=Pochotalons,y=Pochotalats)
Pseudobombaxcoords<-data.frame(x=Pseudobombaxlons,y=Pseudobombaxlats)
Spirothecacoords<-data.frame(x=Spirothecalons,y=Spirothecalats)



Bernoulliacoords<-na.omit(Bernoulliacoords)
Gyrantheracoords<-na.omit(Gyrantheracoords)
Huberodendroncoords<-na.omit(Huberodendroncoords)
Adansoniacoords<-na.omit(Adansoniacoords)
Cavanillesiacoords<-na.omit(Cavanillesiacoords)
Aguiariacoords<-na.omit(Aguiariacoords)
Scleronemacoords<-na.omit(Scleronemacoords)
Catostemacoords<-na.omit(Catostemacoords)
Rhodognaphaloncoords<-na.omit(Rhodognaphaloncoords)
Bombacopsiscoords<-na.omit(Bombacopsiscoords)
Bombaxcoords<-na.omit(Bombaxcoords)
Chorisiacoords<-na.omit(Chorisiacoords)
Ceibacoords<-na.omit(Ceibacoords)
Eriothecacoords<-na.omit(Eriothecacoords)
Neobuchiacoords<-na.omit(Neobuchiacoords)
Pachiracoords<-na.omit(Pachiracoords)
Pochotacoords<-na.omit(Pochotacoords)
Pseudobombaxcoords<-na.omit(Pseudobombaxcoords)
Spirothecacoords<-na.omit(Spirothecacoords)

## join all coords

dfBombacoideae=rbind(Bernoulliacoords, Gyrantheracoords,Huberodendroncoords, Adansoniacoords, Cavanillesiacoords, Aguiariacoords, Scleronemacoords,Catostemacoords, Rhodognaphaloncoords,Bombacopsiscoords, Bombaxcoords, Chorisiacoords , Ceibacoords , Eriothecacoords , Neobuchiacoords, Pachiracoords, Pochotacoords, Pseudobombaxcoords, Spirothecacoords)   

write.csv(dfBombacoideae,file="dfBombacoideae.csv")



##  Pterocarpus clade


Acosmium <-BIEN_occurrence_genus("Acosmium",only.new.world = TRUE)
Arachis <-BIEN_occurrence_genus("Arachis",only.new.world = TRUE)
Brya <-BIEN_occurrence_genus( "Brya" ,only.new.world = TRUE)
Cascaronia <-BIEN_occurrence_genus( "Cascaronia" ,only.new.world = TRUE)
Centrolobium <-BIEN_occurrence_genus( "Centrolobium" ,only.new.world = TRUE)
Chapmannia <-BIEN_occurrence_genus( "Chapmannia" ,only.new.world = TRUE)
Cranocarpu <-BIEN_occurrence_genus( "Cranocarpu" ,only.new.world = TRUE)
Discolobium <-BIEN_occurrence_genus( "Discolobium" ,only.new.world = TRUE)
Etaballia <-BIEN_occurrence_genus( "Etaballia" ,only.new.world = TRUE)
Fiebrigiella <-BIEN_occurrence_genus( "Fiebrigiella" ,only.new.world = TRUE)
Fissicalyx <-BIEN_occurrence_genus( "Fissicalyx" ,only.new.world = TRUE)
Geoffroea <-BIEN_occurrence_genus( "Geoffroea" ,only.new.world = TRUE)
Grazielodendron <-BIEN_occurrence_genus( "Grazielodendron" ,only.new.world = TRUE)
Inocarpus <-BIEN_occurrence_genus( "Inocarpus" ,only.new.world = TRUE)
Maraniona <-BIEN_occurrence_genus( "Maraniona" ,only.new.world = TRUE)
Paramachaerium <-BIEN_occurrence_genus( "Paramachaerium" ,only.new.world = TRUE)
Platymiscium <-BIEN_occurrence_genus( "Platymiscium" ,only.new.world = TRUE)
Platypodium <-BIEN_occurrence_genus( "Platypodium" ,only.new.world = TRUE)
Pterocarpus <-BIEN_occurrence_genus( "Pterocarpus" ,only.new.world = TRUE)
Ramorinoa <-BIEN_occurrence_genus( "Ramorinoa" ,only.new.world = TRUE)
Riedeliella <-BIEN_occurrence_genus( "Riedeliella" ,only.new.world = TRUE)
Stylosanthes <-BIEN_occurrence_genus( "Stylosanthes" ,only.new.world = TRUE)
Tipuana <-BIEN_occurrence_genus( "Tipuana" ,only.new.world = TRUE)


## lats 

Acosmiumlats<-Acosmium$latitude
Arachislats<-Arachis$latitude
Bryalats<-Brya$latitude
Cascaronialats<-Cascaronia$latitude
Centrolobiumlats<-Centrolobium$latitude
Chapmannialats<-Chapmannia$latitude
Cranocarpulats<-Cranocarpu$latitude
Discolobiumlats<-Discolobium$latitude
Etaballialats<-Etaballia$latitude
Fiebrigiellalats<-Fiebrigiella$latitude
Fissicalyxlats<-Fissicalyx$latitude
Geoffroealats<-Geoffroea$latitude
Grazielodendronlats<-Grazielodendron$latitude
Inocarpuslats<-Inocarpus$latitude
Maranionalats<-Maraniona$latitude
Paramachaeriumlats<-Paramachaerium$latitude
Platymisciumlats<-Platymiscium$latitude
Platypodiumlats<-Platypodium$latitude
Pterocarpuslats<-Pterocarpus$latitude
Ramorinoalats<-Ramorinoa$latitude
Riedeliellalats<-Riedeliella$latitude
Stylosantheslats<-Stylosanthes$latitude
Tipuanalats<-Tipuana$latitude


## lons 


Acosmiumlons<-Acosmium$longitude
Arachislons<-Arachis$longitude
Bryalons<-Brya$longitude
Cascaronialons<-Cascaronia$longitude
Centrolobiumlons<-Centrolobium$longitude
Chapmannialons<-Chapmannia$longitude
Cranocarpulons<-Cranocarpu$longitude
Discolobiumlons<-Discolobium$longitude
Etaballialons<-Etaballia$longitude
Fiebrigiellalons<-Fiebrigiella$longitude
Fissicalyxlons<-Fissicalyx$longitude
Geoffroealons<-Geoffroea$longitude
Grazielodendronlons<-Grazielodendron$longitude
Inocarpuslons<-Inocarpus$longitude
Maranionalons<-Maraniona$longitude
Paramachaeriumlons<-Paramachaerium$longitude
Platymisciumlons<-Platymiscium$longitude
Platypodiumlons<-Platypodium$longitude
Pterocarpuslons<-Pterocarpus$longitude
Ramorinoalons<-Ramorinoa$longitude
Riedeliellalons<-Riedeliella$longitude
Stylosantheslons<-Stylosanthes$longitude
Tipuanalons<-Tipuana$longitude

##coords <- data.frame(x=lons,y=lats)


Acosmiumcoords<-data.frame(x=Acosmiumlons,y=Acosmiumlats)
Arachiscoords<-data.frame(x=Arachislons,y=Arachislats)
Bryacoords<-data.frame(x=Bryalons,y=Bryalats)
Cascaroniacoords<-data.frame(x=Cascaronialons,y=Cascaronialats)
Centrolobiumcoords<-data.frame(x=Centrolobiumlons,y=Centrolobiumlats)
Chapmanniacoords<-data.frame(x=Chapmannialons,y=Chapmannialats)
Cranocarpucoords<-data.frame(x=Cranocarpulons,y=Cranocarpulats)
Discolobiumcoords<-data.frame(x=Discolobiumlons,y=Discolobiumlats)
Etaballiacoords<-data.frame(x=Etaballialons,y=Etaballialats)
Fiebrigiellacoords<-data.frame(x=Fiebrigiellalons,y=Fiebrigiellalats)
Fissicalyxcoords<-data.frame(x=Fissicalyxlons,y=Fissicalyxlats)
Geoffroeacoords<-data.frame(x=Geoffroealons,y=Geoffroealats)
Grazielodendroncoords<-data.frame(x=Grazielodendronlons,y=Grazielodendronlats)
Inocarpuscoords<-data.frame(x=Inocarpuslons,y=Inocarpuslats)
Maranionacoords<-data.frame(x=Maranionalons,y=Maranionalats)
Paramachaeriumcoords<-data.frame(x=Paramachaeriumlons,y=Paramachaeriumlats)
Platymisciumcoords<-data.frame(x=Platymisciumlons,y=Platymisciumlats)
Platypodiumcoords<-data.frame(x=Platypodiumlons,y=Platypodiumlats)
Pterocarpuscoords<-data.frame(x=Pterocarpuslons,y=Pterocarpuslats)
Ramorinoacoords<-data.frame(x=Ramorinoalons,y=Ramorinoalats)
Riedeliellacoords<-data.frame(x=Riedeliellalons,y=Riedeliellalats)
Stylosanthescoords<-data.frame(x=Stylosantheslons,y=Stylosantheslats)
Tipuanacoords<-data.frame(x=Tipuanalons,y=Tipuanalats)



##coords <- na.omit(coords)



Acosmiumcoords<-na.omit(Acosmiumcoords)
Arachiscoords<-na.omit(Arachiscoords)
Bryacoords<-na.omit(Bryacoords)
Cascaroniacoords<-na.omit(Cascaroniacoords)
Centrolobiumcoords<-na.omit(Centrolobiumcoords)
Chapmanniacoords<-na.omit(Chapmanniacoords)
Cranocarpucoords<-na.omit(Cranocarpucoords)
Discolobiumcoords<-na.omit(Discolobiumcoords)
Etaballiacoords<-na.omit(Etaballiacoords)
Fiebrigiellacoords<-na.omit(Fiebrigiellacoords)
Fissicalyxcoords<-na.omit(Fissicalyxcoords)
Geoffroeacoords<-na.omit(Geoffroeacoords)
Grazielodendroncoords<-na.omit(Grazielodendroncoords)
Inocarpuscoords<-na.omit(Inocarpuscoords)
Maranionacoords<-na.omit(Maranionacoords)
Paramachaeriumcoords<-na.omit(Paramachaeriumcoords)
Platymisciumcoords<-na.omit(Platymisciumcoords)
Platypodiumcoords<-na.omit(Platypodiumcoords)
Pterocarpuscoords<-na.omit(Pterocarpuscoords)
Ramorinoacoords<-na.omit(Ramorinoacoords)
Riedeliellacoords<-na.omit(Riedeliellacoords)
Stylosanthescoords<-na.omit(Stylosanthescoords)
Tipuanacoords<-na.omit(Tipuanacoords)


## join all coords

dfPteroClade=rbind(Acosmiumcoords, Arachiscoords, Bryacoords, Cascaroniacoords, Centrolobiumcoords, Chapmanniacoords, Cranocarpucoords, Discolobiumcoords, Etaballiacoords, Fiebrigiellacoords, Fissicalyxcoords, Geoffroeacoords, Grazielodendroncoords, Inocarpuscoords, Maranionacoords, Paramachaeriumcoords, Platymisciumcoords, Platypodiumcoords, Pterocarpuscoords, Ramorinoacoords, Riedeliellacoords, Stylosanthescoords, Tipuanacoords)


## Solanaceae fruit

Physalis <-BIEN_occurrence_genus("Physalis",only.new.world = TRUE)
Deprea <-BIEN_occurrence_genus("Deprea",only.new.world = TRUE)

Deprealats<-Deprea$latitude
Physalislats<-Physalis$latitude

Physalislons<-Physalis$longitude
Deprealons<-Deprea$longitude

Physaliscoords<-data.frame(x=Physalislons,y=Physalislats)
Depreacoords<-data.frame(x=Deprealons,y=Deprealats)

Physaliscoords<-na.omit(Physaliscoords)
Depreacoords<-na.omit(Depreacoords)

dfSolanaceae=rbind(Physaliscoords, Depreacoords)

write.table(dfSolanaceae,file="pfSolanaceae.csv")



## Salvinia


Salvinia <-BIEN_occurrence_genus("Salvinia",only.new.world = TRUE)

Salvinialats<-Salvinia$latitude

Salvinialons<-Salvinia$longitude

dfSalvinia<-data.frame(x=Salvinialons,y=Salvinialats)

dfSalvinia<-na.omit(dfSalvinia)



## Passifloroideae

filenames <- c("Adenia", "Ancistrothyrsus","Androsiphonia", "Barteria", "Basananthe", "Crossostemma", "Deidamia",  "Dilkea",   "Efulensia",   "Hollrungia",   "Mitostemma", "Paropsia",  "Paropsiopsis", "Passiflora", "Schlechterina",   "Smeathmannia",   "Viridivia")

for(name in filenames) {
  print(paste(name,"<-BIEN_occurrence_genus(",name,",only.new.world = TRUE)"))
}

Adenia <-BIEN_occurrence_genus( "Adenia" ,only.new.world = TRUE)
Ancistrothyrsus <-BIEN_occurrence_genus( "Ancistrothyrsus" ,only.new.world = TRUE)
Androsiphonia <-BIEN_occurrence_genus( "Androsiphonia" ,only.new.world = TRUE)
Barteria <-BIEN_occurrence_genus( "Barteria" ,only.new.world = TRUE)
Basananthe <-BIEN_occurrence_genus( "Basananthe" ,only.new.world = TRUE)
Crossostemma <-BIEN_occurrence_genus( "Crossostemma" ,only.new.world = TRUE)
Deidamia <-BIEN_occurrence_genus( "Deidamia" ,only.new.world = TRUE)
Dilkea <-BIEN_occurrence_genus( "Dilkea" ,only.new.world = TRUE)
Efulensia <-BIEN_occurrence_genus( "Efulensia" ,only.new.world = TRUE)
Hollrungia <-BIEN_occurrence_genus( "Hollrungia" ,only.new.world = TRUE)
Mitostemma <-BIEN_occurrence_genus( "Mitostemma" ,only.new.world = TRUE)
Paropsia <-BIEN_occurrence_genus( "Paropsia" ,only.new.world = TRUE)
Paropsiopsis <-BIEN_occurrence_genus( "Paropsiopsis" ,only.new.world = TRUE)
Passiflora <-BIEN_occurrence_genus( "Passiflora" ,only.new.world = TRUE)
Schlechterina <-BIEN_occurrence_genus( "Schlechterina" ,only.new.world = TRUE)
Smeathmannia <-BIEN_occurrence_genus( "Smeathmannia" ,only.new.world = TRUE)
Viridivia <-BIEN_occurrence_genus( "Viridivia" ,only.new.world = TRUE)




Adenialats<-Adenia$latitude
Ancistrothyrsuslats<-Ancistrothyrsus$latitude
Androsiphonialats<-Androsiphonia$latitude
Barterialats<-Barteria$latitude
Basananthelats<-Basananthe$latitude
Crossostemmalats<-Crossostemma$latitude
Deidamialats<-Deidamia$latitude
Dilkealats<-Dilkea$latitude
Efulensialats<-Efulensia$latitude
Hollrungialats<-Hollrungia$latitude
Mitostemmalats<-Mitostemma$latitude
Paropsialats<-Paropsia$latitude
Paropsiopsislats<-Paropsiopsis$latitude
Passifloralats<-Passiflora$latitude
Schlechterinalats<-Schlechterina$latitude
Smeathmannialats<-Smeathmannia$latitude
Viridivialats<-Viridivia$latitude


Adenialons<-Adenia$longitude
Ancistrothyrsuslons<-Ancistrothyrsus$longitude
Androsiphonialons<-Androsiphonia$longitude
Barterialons<-Barteria$longitude
Basananthelons<-Basananthe$longitude
Crossostemmalons<-Crossostemma$longitude
Deidamialons<-Deidamia$longitude
Dilkealons<-Dilkea$longitude
Efulensialons<-Efulensia$longitude
Hollrungialons<-Hollrungia$longitude
Mitostemmalons<-Mitostemma$longitude
Paropsialons<-Paropsia$longitude
Paropsiopsislons<-Paropsiopsis$longitude
Passifloralons<-Passiflora$longitude
Schlechterinalons<-Schlechterina$longitude
Smeathmannialons<-Smeathmannia$longitude
Viridivialons<-Viridivia$longitude



Adeniacoords<-data.frame(x=Adenialons,y=Adenialats)
Ancistrothyrsuscoords<-data.frame(x=Ancistrothyrsuslons,y=Ancistrothyrsuslats)
Androsiphoniacoords<-data.frame(x=Androsiphonialons,y=Androsiphonialats)
Barteriacoords<-data.frame(x=Barterialons,y=Barterialats)
Basananthecoords<-data.frame(x=Basananthelons,y=Basananthelats)
Crossostemmacoords<-data.frame(x=Crossostemmalons,y=Crossostemmalats)
Deidamiacoords<-data.frame(x=Deidamialons,y=Deidamialats)
Dilkeacoords<-data.frame(x=Dilkealons,y=Dilkealats)
Efulensiacoords<-data.frame(x=Efulensialons,y=Efulensialats)
Hollrungiacoords<-data.frame(x=Hollrungialons,y=Hollrungialats)
Mitostemmacoords<-data.frame(x=Mitostemmalons,y=Mitostemmalats)
Paropsiacoords<-data.frame(x=Paropsialons,y=Paropsialats)
Paropsiopsiscoords<-data.frame(x=Paropsiopsislons,y=Paropsiopsislats)
Passifloracoords<-data.frame(x=Passifloralons,y=Passifloralats)
Schlechterinacoords<-data.frame(x=Schlechterinalons,y=Schlechterinalats)
Smeathmanniacoords<-data.frame(x=Smeathmannialons,y=Smeathmannialats)
Viridiviacoords<-data.frame(x=Viridivialons,y=Viridivialats)

dfPassifloroideae=rbind(Adeniacoords, Ancistrothyrsuscoords, Androsiphoniacoords, Barteriacoords, Basananthecoords, Crossostemmacoords, Deidamiacoords, Dilkeacoords, Efulensiacoords, Hollrungiacoords, Mitostemmacoords, Paropsiacoords, Paropsiopsiscoords, Passifloracoords, Schlechterinacoords, Smeathmanniacoords, Viridiviacoords)
dfPassifloroideae=na.omit(dfPassifloroideae)



## Menispermaceae

##Old world: Stephania, Perichasma, Antizoma, Cyclea

Cissampelos


Cissampelos <-BIEN_occurrence_genus("Cissampelos",only.new.world = TRUE)

Cissampeloslats<-Cissampelos$latitude

Cissampeloslons<-Cissampelos$longitude

dfCissampelos<-data.frame(x=Cissampeloslons,y=Cissampeloslats)

dfCissampelos<-na.omit(dfCissampelos)


## List of list

MacrofossilLibrary=list(estMenispermaceae, estPassifloroideae, estSalvinia, estSolanaceae,estPteroClade)
names(MacrofossilLibrary) <- c("Menispermaceae","Passifloroideae", "Salvinia", "Solanaceae", "Pterocarpus.Clade")



#########################################################################################################
#########################################################################################################
#########################################################################################################

        ###  Libraries BIO 1 and BIO 12  ###

#########################################################################################################
#########################################################################################################
#########################################################################################################


library(raster)
library(KernSmooth)


#########################################################################################################
##Macrofossils##
#########################################################################################################

##pteroClade

dfPteroCladeCoords <- read.csv("~/dfPteroClade.csv", sep="")
pteroCoords <- data.frame(x=dfPteroCladeCoords$x,y=dfPteroCladeCoords$y)
pteroCoords <- na.omit(pteroCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsptero <- SpatialPoints(pteroCoords, proj4string = r@crs)
valuesptero <- extract(r,pointsptero)
dfPteroClade <- cbind.data.frame(coordinates(pointsptero),valuesptero)


MAPPtero= as.numeric(dfPteroClade$MAP)
MAPPtero= na.omit(MAPPtero)
hMAPPteroClade=dpik(MAPPtero)


MATPtero= as.numeric(dfPteroClade$MAT)
MATPtero= na.omit(MATPtero)
hMATPteroClade <- dpik(MATPtero)

xPtero <- cbind(MAPPtero,MATPtero)
estPteroClade <- bkde2D(xPtero, bandwidth=c(hMAPPteroClade,hMATPteroClade),range.x=list(c(0,3000), c(0,300 )))
image(estPteroClade$x1, estPteroClade$x2, estPteroClade$fhat) 



## Menispermaceae

dfCissampelosCoords <- read.csv("~/dfCissampelos.csv", sep="")
CissampelosCoords <- data.frame(x=dfCissampelosCoords$x,y=dfCissampelosCoords$y)
CissampelosCoords <- na.omit(CissampelosCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsCissampelos <- SpatialPoints(CissampelosCoords, proj4string = r@crs)
valuesCissampelos <- extract(r,pointsCissampelos)
dfCissampelos <- cbind.data.frame(coordinates(pointsCissampelos),valuesCissampelos)


MAPCissampelos= as.numeric(dfCissampelos$MAP)
MAPCissampelos= na.omit(MAPCissampelos)
hMAPCissampelos=dpik(MAPCissampelos)


MATCissampelos= as.numeric(dfCissampelos$MAT)
MATCissampelos= na.omit(MATCissampelos)
hMATCissampelos <- dpik(MATCissampelos)

xCissampelos <- cbind(MAPCissampelos,MATCissampelos)
estCissampelos <- bkde2D(xCissampelos, bandwidth=c(hMAPCissampelos,hMATCissampelos),range.x=list(c(0,3000), c(0,300 )))
image(estCissampelos$x1, estCissampelos$x2, estCissampelos$fhat) 


##Passifloroideae

dfPassifloroideaeCoords <- read.csv("~/dfPassifloroideae.csv", sep="")
PassifloroideaeCoords <- data.frame(x=dfPassifloroideaeCoords$x,y=dfPassifloroideaeCoords$y)
PassifloroideaeCoords <- na.omit(PassifloroideaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsPassifloroideae <- SpatialPoints(PassifloroideaeCoords, proj4string = r@crs)
valuesPassifloroideae <- extract(r,pointsPassifloroideae)
dfPassifloroideae <- cbind.data.frame(coordinates(pointsPassifloroideae),valuesPassifloroideae)


MAPPassifloroideae= as.numeric(dfPassifloroideae$MAP)
MAPPassifloroideae= na.omit(MAPPassifloroideae)
hMAPPassifloroideae=dpik(MAPPassifloroideae)


MATPassifloroideae= as.numeric(dfPassifloroideae$MAT)
MATPassifloroideae= na.omit(MATPassifloroideae)
hMATPassifloroideae <- dpik(MATPassifloroideae)

xPassifloroideae <- cbind(MAPPassifloroideae,MATPassifloroideae)
estPassifloroideae <- bkde2D(xPassifloroideae, bandwidth=c(hMAPPassifloroideae,hMATPassifloroideae),range.x=list(c(0,3000), c(0,300 )))
image(estPassifloroideae$x1, estPassifloroideae$x2, estPassifloroideae$fhat) 



## Salvinia

dfSalviniaCoords <- read.csv("~/dfSalvinia.csv", sep="")
SalviniaCoords <- data.frame(x=dfSalviniaCoords$x,y=dfSalviniaCoords$y)
SalviniaCoords <- na.omit(SalviniaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsSalvinia <- SpatialPoints(SalviniaCoords, proj4string = r@crs)
valuesSalvinia <- extract(r,pointsSalvinia)
dfSalvinia <- cbind.data.frame(coordinates(pointsSalvinia),valuesSalvinia)


MAPSalvinia= as.numeric(dfSalvinia$MAP)
MAPSalvinia= na.omit(MAPSalvinia)
hMAPSalvinia=dpik(MAPSalvinia)


MATSalvinia= as.numeric(dfSalvinia$MAT)
MATSalvinia= na.omit(MATSalvinia)
hMATSalvinia <- dpik(MATSalvinia)

xSalvinia <- cbind(MAPSalvinia,MATSalvinia)
estSalvinia <- bkde2D(xSalvinia, bandwidth=c(hMAPSalvinia,hMATSalvinia),range.x=list(c(0,3000), c(0,300 )))
image(estSalvinia$x1, estSalvinia$x2, estSalvinia$fhat) 


## Solanaceae


dfSolanaceae=read.csv("~/dfSolanaceae.csv", sep="")
SolanaceaeCoords <- data.frame(x=dfSolanaceae$x,y=dfSolanaceae$y)
SolanaceaeCoords <- na.omit(SolanaceaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsSolanaceae <- SpatialPoints(SolanaceaeCoords, proj4string = r@crs)
valuesSolanaceae <- extract(r,pointsSolanaceae)
dfSolanaceae <- cbind.data.frame(coordinates(pointsSolanaceae),valuesSolanaceae)


MATSolanaceae= as.numeric(dfSolanaceae$MAT)
MATSolanaceae= na.omit(MATSolanaceae)
hMATSolanaceae <- dpik(MATSolanaceae)


MAPSolanaceae= as.numeric(dfSolanaceae$MAP)
MAPSolanaceae= na.omit(MAPSolanaceae)
hMAPSolanaceae=dpik(MAPSolanaceae)


xSolanaceae <- cbind(MAPSolanaceae,MATSolanaceae)
estSolanaceae <- bkde2D(xSolanaceae, bandwidth=c(hMAPSolanaceae,hMATSolanaceae),range.x=list(c(0,3000), c(0,300 )))
image(estSolanaceae$x1, estSolanaceae$x2, estSolanaceae$fhat)


## List of list

MacrofossilLibrary1_12=list(estCissampelos, estPassifloroideae, estSalvinia, estSolanaceae,estPteroClade)
names(MacrofossilLibrary1_12) <- c("Menispermaceae","Passifloroideae", "Salvinia", "Solanaceae", "Pterocarpus.Clade")

save(MacrofossilLibrary1_12,file="MacrofossilLibrary1_12.RData")







#########################################################################################################
##Microfossils##
#########################################################################################################


## AlisCladeA


dfAlisCladeA=read.csv("~/dfAlisCladeA.csv", sep="")
AlisCladeACoords <- data.frame(x=dfAlisCladeA$x,y=dfAlisCladeA$y)
AlisCladeACoords <- na.omit(AlisCladeACoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsAlisCladeA <- SpatialPoints(AlisCladeACoords, proj4string = r@crs)
valuesAlisCladeA <- extract(r,pointsAlisCladeA)
dfAlisCladeA <- cbind.data.frame(coordinates(pointsAlisCladeA),valuesAlisCladeA)


MATAlisCladeA= as.numeric(dfAlisCladeA$MAT)
MATAlisCladeA= na.omit(MATAlisCladeA)
hMATAlisCladeA <- dpik(MATAlisCladeA)


MAPAlisCladeA= as.numeric(dfAlisCladeA$MAP)
MAPAlisCladeA= na.omit(MAPAlisCladeA)
hMAPAlisCladeA=dpik(MAPAlisCladeA)


x <- cbind(MAPAlisCladeA,MATAlisCladeA)
estAlisCladeA <- bkde2D(x, bandwidth=c(hMAPAlisCladeA,hMATAlisCladeA),range.x=list(c(0,5000), c(0,300 )))
image(estAlisCladeA$x1, estAlisCladeA$x2, estAlisCladeA$fhat)



## Bombacoideae


dfBombacoideae=read.csv("~/dfBombacoideae.csv", sep="")
BombacoideaeCoords <- data.frame(x=dfBombacoideae$x,y=dfBombacoideae$y)
BombacoideaeCoords <- na.omit(BombacoideaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsBombacoideae <- SpatialPoints(BombacoideaeCoords, proj4string = r@crs)
valuesBombacoideae <- extract(r,pointsBombacoideae)
dfBombacoideae <- cbind.data.frame(coordinates(pointsBombacoideae),valuesBombacoideae)


MATBombacoideae= as.numeric(dfBombacoideae$MAT)
MATBombacoideae= na.omit(MATBombacoideae)
hMATBombacoideae <- dpik(MATBombacoideae)


MAPBombacoideae= as.numeric(dfBombacoideae$MAP)
MAPBombacoideae= na.omit(MAPBombacoideae)
hMAPBombacoideae=dpik(MAPBombacoideae)


x <- cbind(MAPBombacoideae,MATBombacoideae)
estBombacoideae <- bkde2D(x, bandwidth=c(hMAPBombacoideae,hMATBombacoideae),range.x=list(c(0,5000), c(0,300 )))
image(estBombacoideae$x1, estBombacoideae$x2, estBombacoideae$fhat)





## Chrysophyllum


dfChrysophyllum=read.csv("~/dfChrysophyllum.csv", sep="")
ChrysophyllumCoords <- data.frame(x=dfChrysophyllum$x,y=dfChrysophyllum$y)
ChrysophyllumCoords <- na.omit(ChrysophyllumCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsChrysophyllum <- SpatialPoints(ChrysophyllumCoords, proj4string = r@crs)
valuesChrysophyllum <- extract(r,pointsChrysophyllum)
dfChrysophyllum <- cbind.data.frame(coordinates(pointsChrysophyllum),valuesChrysophyllum)


MATChrysophyllum= as.numeric(dfChrysophyllum$MAT)
MATChrysophyllum= na.omit(MATChrysophyllum)
hMATChrysophyllum <- dpik(MATChrysophyllum)


MAPChrysophyllum= as.numeric(dfChrysophyllum$MAP)
MAPChrysophyllum= na.omit(MAPChrysophyllum)
hMAPChrysophyllum=dpik(MAPChrysophyllum)


x <- cbind(MAPChrysophyllum,MATChrysophyllum)
estChrysophyllum <- bkde2D(x, bandwidth=c(hMAPChrysophyllum,hMATChrysophyllum),range.x=list(c(0,5000), c(0,300 )))
image(estChrysophyllum$x1, estChrysophyllum$x2, estChrysophyllum$fhat)


## Eumalvoideae


dfEumalvoideae=read.csv("~/dfEumalvoideae.csv", sep="")
EumalvoideaeCoords <- data.frame(x=dfEumalvoideae$x,y=dfEumalvoideae$y)
EumalvoideaeCoords <- na.omit(EumalvoideaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsEumalvoideae <- SpatialPoints(EumalvoideaeCoords, proj4string = r@crs)
valuesEumalvoideae <- extract(r,pointsEumalvoideae)
dfEumalvoideae <- cbind.data.frame(coordinates(pointsEumalvoideae),valuesEumalvoideae)


MATEumalvoideae= as.numeric(dfEumalvoideae$MAT)
MATEumalvoideae= na.omit(MATEumalvoideae)
hMATEumalvoideae <- dpik(MATEumalvoideae)


MAPEumalvoideae= as.numeric(dfEumalvoideae$MAP)
MAPEumalvoideae= na.omit(MAPEumalvoideae)
hMAPEumalvoideae=dpik(MAPEumalvoideae)


x <- cbind(MAPEumalvoideae,MATEumalvoideae)
estEumalvoideae <- bkde2D(x, bandwidth=c(hMAPEumalvoideae,hMATEumalvoideae),range.x=list(c(0,5000), c(0,300 )))
image(estEumalvoideae$x1, estEumalvoideae$x2, estEumalvoideae$fhat)


## Grewieae


dfGrewieae=read.csv("~/dfGrewieae.csv", sep="")
GrewieaeCoords <- data.frame(x=dfGrewieae$x,y=dfGrewieae$y)
GrewieaeCoords <- na.omit(GrewieaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsGrewieae <- SpatialPoints(GrewieaeCoords, proj4string = r@crs)
valuesGrewieae <- extract(r,pointsGrewieae)
dfGrewieae <- cbind.data.frame(coordinates(pointsGrewieae),valuesGrewieae)


MATGrewieae= as.numeric(dfGrewieae$MAT)
MATGrewieae= na.omit(MATGrewieae)
hMATGrewieae <- dpik(MATGrewieae)


MAPGrewieae= as.numeric(dfGrewieae$MAP)
MAPGrewieae= na.omit(MAPGrewieae)
hMAPGrewieae=dpik(MAPGrewieae)


x <- cbind(MAPGrewieae,MATGrewieae)
estGrewieae <- bkde2D(x, bandwidth=c(hMAPGrewieae,hMATGrewieae),range.x=list(c(0,5000), c(0,300 )))
image(estGrewieae$x1, estGrewieae$x2, estGrewieae$fhat)



## Mauritia


dfMauritia=read.csv("~/dfMauritia.csv", sep="")
MauritiaCoords <- data.frame(x=dfMauritia$x,y=dfMauritia$y)
MauritiaCoords <- na.omit(MauritiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsMauritia <- SpatialPoints(MauritiaCoords, proj4string = r@crs)
valuesMauritia <- extract(r,pointsMauritia)
dfMauritia <- cbind.data.frame(coordinates(pointsMauritia),valuesMauritia)


MATMauritia= as.numeric(dfMauritia$MAT)
MATMauritia= na.omit(MATMauritia)
hMATMauritia <- dpik(MATMauritia)


MAPMauritia= as.numeric(dfMauritia$MAP)
MAPMauritia= na.omit(MAPMauritia)
hMAPMauritia=dpik(MAPMauritia)


x <- cbind(MAPMauritia,MATMauritia)
estMauritia <- bkde2D(x, bandwidth=c(hMAPMauritia,hMATMauritia),range.x=list(c(0,5000), c(0,300 )))
image(estMauritia$x1, estMauritia$x2, estMauritia$fhat)


## Merremia


dfMerremia=read.csv("~/dfMerremia.csv", sep="")
MerremiaCoords <- data.frame(x=dfMerremia$x,y=dfMerremia$y)
MerremiaCoords <- na.omit(MerremiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsMerremia <- SpatialPoints(MerremiaCoords, proj4string = r@crs)
valuesMerremia <- extract(r,pointsMerremia)
dfMerremia <- cbind.data.frame(coordinates(pointsMerremia),valuesMerremia)


MATMerremia= as.numeric(dfMerremia$MAT)
MATMerremia= na.omit(MATMerremia)
hMATMerremia <- dpik(MATMerremia)


MAPMerremia= as.numeric(dfMerremia$MAP)
MAPMerremia= na.omit(MAPMerremia)
hMAPMerremia=dpik(MAPMerremia)


x <- cbind(MAPMerremia,MATMerremia)
estMerremia <- bkde2D(x, bandwidth=c(hMAPMerremia,hMATMerremia),range.x=list(c(0,5000), c(0,300 )))
image(estMerremia$x1, estMerremia$x2, estMerremia$fhat)




## Alchornea


dfAlchornea=read.csv("~/dfAlchornea.csv", sep="")
AlchorneaCoords <- data.frame(x=dfAlchornea$x,y=dfAlchornea$y)
AlchorneaCoords <- na.omit(AlchorneaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsAlchornea <- SpatialPoints(AlchorneaCoords, proj4string = r@crs)
valuesAlchornea <- extract(r,pointsAlchornea)
dfAlchornea <- cbind.data.frame(coordinates(pointsAlchornea),valuesAlchornea)


MATAlchornea= as.numeric(dfAlchornea$MAT)
MATAlchornea= na.omit(MATAlchornea)
hMATAlchornea <- dpik(MATAlchornea)


MAPAlchornea= as.numeric(dfAlchornea$MAP)
MAPAlchornea= na.omit(MAPAlchornea)
hMAPAlchornea=dpik(MAPAlchornea)


x <- cbind(MAPAlchornea,MATAlchornea)
estAlchornea <- bkde2D(x, bandwidth=c(hMAPAlchornea,hMATAlchornea),range.x=list(c(0,5000), c(0,300 )))
image(estAlchornea$x1, estAlchornea$x2, estAlchornea$fhat)





## Amanoa


dfAmanoa=read.csv("~/dfAmanoa.csv", sep="")
AmanoaCoords <- data.frame(x=dfAmanoa$x,y=dfAmanoa$y)
AmanoaCoords <- na.omit(AmanoaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsAmanoa <- SpatialPoints(AmanoaCoords, proj4string = r@crs)
valuesAmanoa <- extract(r,pointsAmanoa)
dfAmanoa <- cbind.data.frame(coordinates(pointsAmanoa),valuesAmanoa)


MATAmanoa= as.numeric(dfAmanoa$MAT)
MATAmanoa= na.omit(MATAmanoa)
hMATAmanoa <- dpik(MATAmanoa)


MAPAmanoa= as.numeric(dfAmanoa$MAP)
MAPAmanoa= na.omit(MAPAmanoa)
hMAPAmanoa=dpik(MAPAmanoa)


x <- cbind(MAPAmanoa,MATAmanoa)
estAmanoa <- bkde2D(x, bandwidth=c(hMAPAmanoa,hMATAmanoa),range.x=list(c(0,5000), c(0,300 )))
image(estAmanoa$x1, estAmanoa$x2, estAmanoa$fhat)



## Polygaleae


dfPolygaleae=read.csv("~/dfPolygaleae.csv", sep="")
PolygaleaeCoords <- data.frame(x=dfPolygaleae$x,y=dfPolygaleae$y)
PolygaleaeCoords <- na.omit(PolygaleaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsPolygaleae <- SpatialPoints(PolygaleaeCoords, proj4string = r@crs)
valuesPolygaleae <- extract(r,pointsPolygaleae)
dfPolygaleae <- cbind.data.frame(coordinates(pointsPolygaleae),valuesPolygaleae)


MATPolygaleae= as.numeric(dfPolygaleae$MAT)
MATPolygaleae= na.omit(MATPolygaleae)
hMATPolygaleae <- dpik(MATPolygaleae)


MAPPolygaleae= as.numeric(dfPolygaleae$MAP)
MAPPolygaleae= na.omit(MAPPolygaleae)
hMAPPolygaleae=dpik(MAPPolygaleae)


x <- cbind(MAPPolygaleae,MATPolygaleae)
estPolygaleae <- bkde2D(x, bandwidth=c(hMAPPolygaleae,hMATPolygaleae),range.x=list(c(0,5000), c(0,300 )))
image(estPolygaleae$x1, estPolygaleae$x2, estPolygaleae$fhat)






## Malmea


dfMalmea=read.csv("~/dfMalmea.csv", sep="")
MalmeaCoords <- data.frame(x=dfMalmea$x,y=dfMalmea$y)
MalmeaCoords <- na.omit(MalmeaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsMalmea <- SpatialPoints(MalmeaCoords, proj4string = r@crs)
valuesMalmea <- extract(r,pointsMalmea)
dfMalmea <- cbind.data.frame(coordinates(pointsMalmea),valuesMalmea)


MATMalmea= as.numeric(dfMalmea$MAT)
MATMalmea= na.omit(MATMalmea)
hMATMalmea <- dpik(MATMalmea)


MAPMalmea= as.numeric(dfMalmea$MAP)
MAPMalmea= na.omit(MAPMalmea)
hMAPMalmea=dpik(MAPMalmea)


x <- cbind(MAPMalmea,MATMalmea)
estMalmea <- bkde2D(x, bandwidth=c(hMAPMalmea,hMATMalmea),range.x=list(c(0,5000), c(0,300 )))
image(estMalmea$x1, estMalmea$x2, estMalmea$fhat)





## Ludwigia


dfLudwigia=read.csv("~/dfLudwigia.csv", sep="")
LudwigiaCoords <- data.frame(x=dfLudwigia$x,y=dfLudwigia$y)
LudwigiaCoords <- na.omit(LudwigiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsLudwigia <- SpatialPoints(LudwigiaCoords, proj4string = r@crs)
valuesLudwigia <- extract(r,pointsLudwigia)
dfLudwigia <- cbind.data.frame(coordinates(pointsLudwigia),valuesLudwigia)


MATLudwigia= as.numeric(dfLudwigia$MAT)
MATLudwigia= na.omit(MATLudwigia)
hMATLudwigia <- dpik(MATLudwigia)


MAPLudwigia= as.numeric(dfLudwigia$MAP)
MAPLudwigia= na.omit(MAPLudwigia)
hMAPLudwigia=dpik(MAPLudwigia)


x <- cbind(MAPLudwigia,MATLudwigia)
estLudwigia <- bkde2D(x, bandwidth=c(hMAPLudwigia,hMATLudwigia),range.x=list(c(0,5000), c(0,300 )))
image(estLudwigia$x1, estLudwigia$x2, estLudwigia$fhat)


## Sapium


dfSapium=read.csv("~/dfSapium.csv", sep="")
SapiumCoords <- data.frame(x=dfSapium$x,y=dfSapium$y)
SapiumCoords <- na.omit(SapiumCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsSapium <- SpatialPoints(SapiumCoords, proj4string = r@crs)
valuesSapium <- extract(r,pointsSapium)
dfSapium <- cbind.data.frame(coordinates(pointsSapium),valuesSapium)


MATSapium= as.numeric(dfSapium$MAT)
MATSapium= na.omit(MATSapium)
hMATSapium <- dpik(MATSapium)


MAPSapium= as.numeric(dfSapium$MAP)
MAPSapium= na.omit(MAPSapium)
hMAPSapium=dpik(MAPSapium)


x <- cbind(MAPSapium,MATSapium)
estSapium <- bkde2D(x, bandwidth=c(hMAPSapium,hMATSapium),range.x=list(c(0,5000), c(0,300 )))
image(estSapium$x1, estSapium$x2, estSapium$fhat)



## Phytelephas


dfPhytelephas=read.csv("~/dfPhytelephas.csv", sep="")
PhytelephasCoords <- data.frame(x=dfPhytelephas$x,y=dfPhytelephas$y)
PhytelephasCoords <- na.omit(PhytelephasCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsPhytelephas <- SpatialPoints(PhytelephasCoords, proj4string = r@crs)
valuesPhytelephas <- extract(r,pointsPhytelephas)
dfPhytelephas <- cbind.data.frame(coordinates(pointsPhytelephas),valuesPhytelephas)


MATPhytelephas= as.numeric(dfPhytelephas$MAT)
MATPhytelephas= na.omit(MATPhytelephas)
hMATPhytelephas <- dpik(MATPhytelephas)


MAPPhytelephas= as.numeric(dfPhytelephas$MAP)
MAPPhytelephas= na.omit(MAPPhytelephas)
hMAPPhytelephas=dpik(MAPPhytelephas)


x <- cbind(MAPPhytelephas,MATPhytelephas)
estPhytelephas <- bkde2D(x, bandwidth=c(hMAPPhytelephas,hMATPhytelephas),range.x=list(c(0,5000), c(0,300 )))
image(estPhytelephas$x1, estPhytelephas$x2, estPhytelephas$fhat)




## Iriartea


dfIriartea=read.csv("~/dfIriartea.csv", sep="")
IriarteaCoords <- data.frame(x=dfIriartea$x,y=dfIriartea$y)
IriarteaCoords <- na.omit(IriarteaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsIriartea <- SpatialPoints(IriarteaCoords, proj4string = r@crs)
valuesIriartea <- extract(r,pointsIriartea)
dfIriartea <- cbind.data.frame(coordinates(pointsIriartea),valuesIriartea)


MATIriartea= as.numeric(dfIriartea$MAT)
MATIriartea= na.omit(MATIriartea)
hMATIriartea <- dpik(MATIriartea)


MAPIriartea= as.numeric(dfIriartea$MAP)
MAPIriartea= na.omit(MAPIriartea)
hMAPIriartea=dpik(MAPIriartea)


x <- cbind(MAPIriartea,MATIriartea)
estIriartea <- bkde2D(x, bandwidth=c(hMAPIriartea,hMATIriartea),range.x=list(c(0,5000), c(0,300 )))
image(estIriartea$x1, estIriartea$x2, estIriartea$fhat)





## Aguiaria


dfAguiaria=read.csv("~/dfAguiaria.csv", sep=",")
AguiariaCoords <- data.frame(x=dfAguiaria$x,y=dfAguiaria$y)
AguiariaCoords <- na.omit(AguiariaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsAguiaria <- SpatialPoints(AguiariaCoords, proj4string = r@crs)
valuesAguiaria <- extract(r,pointsAguiaria)
dfAguiaria <- cbind.data.frame(coordinates(pointsAguiaria),valuesAguiaria)


MATAguiaria= as.numeric(dfAguiaria$MAT)
MATAguiaria= na.omit(MATAguiaria)
hMATAguiaria <- dpik(MATAguiaria)


MAPAguiaria= as.numeric(dfAguiaria$MAP)
MAPAguiaria= na.omit(MAPAguiaria)
hMAPAguiaria=dpik(MAPAguiaria)


x <- cbind(MAPAguiaria,MATAguiaria)
estAguiaria <- bkde2D(x,bandwidth =c(7,7), range.x=list(c(0,5000), c(0,300 )))
image(estAguiaria$x1, estAguiaria$x2, estAguiaria$fhat)



## Anemia


dfAnemia=read.csv("~/dfAnemia.csv", sep=",")
AnemiaCoords <- data.frame(x=dfAnemia$x,y=dfAnemia$y)
AnemiaCoords <- na.omit(AnemiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsAnemia <- SpatialPoints(AnemiaCoords, proj4string = r@crs)
valuesAnemia <- extract(r,pointsAnemia)
dfAnemia <- cbind.data.frame(coordinates(pointsAnemia),valuesAnemia)


MATAnemia= as.numeric(dfAnemia$MAT)
MATAnemia= na.omit(MATAnemia)
hMATAnemia <- dpik(MATAnemia)


MAPAnemia= as.numeric(dfAnemia$MAP)
MAPAnemia= na.omit(MAPAnemia)
hMAPAnemia=dpik(MAPAnemia)


x <- cbind(MAPAnemia,MATAnemia)
estAnemia <- bkde2D(x, bandwidth=c(hMAPAnemia,hMATAnemia),range.x=list(c(0,5000), c(0,300 )))
image(estAnemia$x1, estAnemia$x2, estAnemia$fhat)


## Araucaria


dfAraucaria=read.csv("~/dfAraucaria.csv", sep=",")
AraucariaCoords <- data.frame(x=dfAraucaria$x,y=dfAraucaria$y)
AraucariaCoords <- na.omit(AraucariaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsAraucaria <- SpatialPoints(AraucariaCoords, proj4string = r@crs)
valuesAraucaria <- extract(r,pointsAraucaria)
dfAraucaria <- cbind.data.frame(coordinates(pointsAraucaria),valuesAraucaria)


MATAraucaria= as.numeric(dfAraucaria$MAT)
MATAraucaria= na.omit(MATAraucaria)
hMATAraucaria <- dpik(MATAraucaria)


MAPAraucaria= as.numeric(dfAraucaria$MAP)
MAPAraucaria= na.omit(MAPAraucaria)
hMAPAraucaria=dpik(MAPAraucaria)


x <- cbind(MAPAraucaria,MATAraucaria)
estAraucaria <- bkde2D(x, bandwidth=c(hMAPAraucaria,hMATAraucaria),range.x=list(c(0,5000), c(0,300 )))
image(estAraucaria$x1, estAraucaria$x2, estAraucaria$fhat)



## Catostemma


dfCatostemma=read.csv("~/dfCatostemma.csv", sep=",")
CatostemmaCoords <- data.frame(x=dfCatostemma$x,y=dfCatostemma$y)
CatostemmaCoords <- na.omit(CatostemmaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsCatostemma <- SpatialPoints(CatostemmaCoords, proj4string = r@crs)
valuesCatostemma <- extract(r,pointsCatostemma)
dfCatostemma <- cbind.data.frame(coordinates(pointsCatostemma),valuesCatostemma)


MATCatostemma= as.numeric(dfCatostemma$MAT)
MATCatostemma= na.omit(MATCatostemma)
hMATCatostemma <- dpik(MATCatostemma)


MAPCatostemma= as.numeric(dfCatostemma$MAP)
MAPCatostemma= na.omit(MAPCatostemma)
hMAPCatostemma=dpik(MAPCatostemma)


x <- cbind(MAPCatostemma,MATCatostemma)
estCatostemma <- bkde2D(x, bandwidth=c(hMAPCatostemma,hMATCatostemma),range.x=list(c(0,5000), c(0,300 )))
image(estCatostemma$x1, estCatostemma$x2, estCatostemma$fhat)



## Cremastosperma


dfCremastosperma=read.csv("~/dfCremastosperma.csv", sep=",")
CremastospermaCoords <- data.frame(x=dfCremastosperma$x,y=dfCremastosperma$y)
CremastospermaCoords <- na.omit(CremastospermaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsCremastosperma <- SpatialPoints(CremastospermaCoords, proj4string = r@crs)
valuesCremastosperma <- extract(r,pointsCremastosperma)
dfCremastosperma <- cbind.data.frame(coordinates(pointsCremastosperma),valuesCremastosperma)


MATCremastosperma= as.numeric(dfCremastosperma$MAT)
MATCremastosperma= na.omit(MATCremastosperma)
hMATCremastosperma <- dpik(MATCremastosperma)


MAPCremastosperma= as.numeric(dfCremastosperma$MAP)
MAPCremastosperma= na.omit(MAPCremastosperma)
hMAPCremastosperma=dpik(MAPCremastosperma)


x <- cbind(MAPCremastosperma,MATCremastosperma)
estCremastosperma <- bkde2D(x, bandwidth=c(hMAPCremastosperma,hMATCremastosperma),range.x=list(c(0,5000), c(0,300 )))
image(estCremastosperma$x1, estCremastosperma$x2, estCremastosperma$fhat)




## Dalechampia


dfDalechampia=read.csv("~/dfDalechampia.csv", sep=",")
DalechampiaCoords <- data.frame(x=dfDalechampia$x,y=dfDalechampia$y)
DalechampiaCoords <- na.omit(DalechampiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsDalechampia <- SpatialPoints(DalechampiaCoords, proj4string = r@crs)
valuesDalechampia <- extract(r,pointsDalechampia)
dfDalechampia <- cbind.data.frame(coordinates(pointsDalechampia),valuesDalechampia)


MATDalechampia= as.numeric(dfDalechampia$MAT)
MATDalechampia= na.omit(MATDalechampia)
hMATDalechampia <- dpik(MATDalechampia)


MAPDalechampia= as.numeric(dfDalechampia$MAP)
MAPDalechampia= na.omit(MAPDalechampia)
hMAPDalechampia=dpik(MAPDalechampia)


x <- cbind(MAPDalechampia,MATDalechampia)
estDalechampia <- bkde2D(x, bandwidth=c(hMAPDalechampia,hMATDalechampia),range.x=list(c(0,5000), c(0,300 )))
image(estDalechampia$x1, estDalechampia$x2, estDalechampia$fhat)





## Micropholis


dfMicropholis=read.csv("~/dfMicropholis.csv", sep=",")
MicropholisCoords <- data.frame(x=dfMicropholis$x,y=dfMicropholis$y)
MicropholisCoords <- na.omit(MicropholisCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsMicropholis <- SpatialPoints(MicropholisCoords, proj4string = r@crs)
valuesMicropholis <- extract(r,pointsMicropholis)
dfMicropholis <- cbind.data.frame(coordinates(pointsMicropholis),valuesMicropholis)


MATMicropholis= as.numeric(dfMicropholis$MAT)
MATMicropholis= na.omit(MATMicropholis)
hMATMicropholis <- dpik(MATMicropholis)


MAPMicropholis= as.numeric(dfMicropholis$MAP)
MAPMicropholis= na.omit(MAPMicropholis)
hMAPMicropholis=dpik(MAPMicropholis)


x <- cbind(MAPMicropholis,MATMicropholis)
estMicropholis <- bkde2D(x, bandwidth=c(hMAPMicropholis,hMATMicropholis),range.x=list(c(0,5000), c(0,300 )))
image(estMicropholis$x1, estMicropholis$x2, estMicropholis$fhat)




## Pelliciera


dfPelliciera=read.csv("~/dfPelliciera.csv", sep=",")
PellicieraCoords <- data.frame(x=dfPelliciera$x,y=dfPelliciera$y)
PellicieraCoords <- na.omit(PellicieraCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsPelliciera <- SpatialPoints(PellicieraCoords, proj4string = r@crs)
valuesPelliciera <- extract(r,pointsPelliciera)
dfPelliciera <- cbind.data.frame(coordinates(pointsPelliciera),valuesPelliciera)


MATPelliciera= as.numeric(dfPelliciera$MAT)
MATPelliciera= na.omit(MATPelliciera)
hMATPelliciera <- dpik(MATPelliciera)


MAPPelliciera= as.numeric(dfPelliciera$MAP)
MAPPelliciera= na.omit(MAPPelliciera)
hMAPPelliciera=dpik(MAPPelliciera)


x <- cbind(MAPPelliciera,MATPelliciera)
estPelliciera <- bkde2D(x, bandwidth=c(hMAPPelliciera,hMATPelliciera),range.x=list(c(0,5000), c(0,300 )))
image(estPelliciera$x1, estPelliciera$x2, estPelliciera$fhat)




## Podocarpus


dfPodocarpus=read.csv("~/dfPodocarpus.csv", sep=",")
PodocarpusCoords <- data.frame(x=dfPodocarpus$x,y=dfPodocarpus$y)
PodocarpusCoords <- na.omit(PodocarpusCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsPodocarpus <- SpatialPoints(PodocarpusCoords, proj4string = r@crs)
valuesPodocarpus <- extract(r,pointsPodocarpus)
dfPodocarpus <- cbind.data.frame(coordinates(pointsPodocarpus),valuesPodocarpus)


MATPodocarpus= as.numeric(dfPodocarpus$MAT)
MATPodocarpus= na.omit(MATPodocarpus)
hMATPodocarpus <- dpik(MATPodocarpus)


MAPPodocarpus= as.numeric(dfPodocarpus$MAP)
MAPPodocarpus= na.omit(MAPPodocarpus)
hMAPPodocarpus=dpik(MAPPodocarpus)


x <- cbind(MAPPodocarpus,MATPodocarpus)
estPodocarpus <- bkde2D(x, bandwidth=c(hMAPPodocarpus,hMATPodocarpus),range.x=list(c(0,5000), c(0,300 )))
image(estPodocarpus$x1, estPodocarpus$x2, estPodocarpus$fhat)





## Polypodium


dfPolypodium=read.csv("~/dfPolypodium.csv", sep=",")
PolypodiumCoords <- data.frame(x=dfPolypodium$x,y=dfPolypodium$y)
PolypodiumCoords <- na.omit(PolypodiumCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsPolypodium <- SpatialPoints(PolypodiumCoords, proj4string = r@crs)
valuesPolypodium <- extract(r,pointsPolypodium)
dfPolypodium <- cbind.data.frame(coordinates(pointsPolypodium),valuesPolypodium)


MATPolypodium= as.numeric(dfPolypodium$MAT)
MATPolypodium= na.omit(MATPolypodium)
hMATPolypodium <- dpik(MATPolypodium)


MAPPolypodium= as.numeric(dfPolypodium$MAP)
MAPPolypodium= na.omit(MAPPolypodium)
hMAPPolypodium=dpik(MAPPolypodium)


x <- cbind(MAPPolypodium,MATPolypodium)
estPolypodium <- bkde2D(x, bandwidth=c(hMAPPolypodium,hMATPolypodium),range.x=list(c(0,5000), c(0,300 )))
image(estPolypodium$x1, estPolypodium$x2, estPolypodium$fhat)






## Quararibea


dfQuararibea=read.csv("~/dfQuararibea.csv", sep=",")
QuararibeaCoords <- data.frame(x=dfQuararibea$x,y=dfQuararibea$y)
QuararibeaCoords <- na.omit(QuararibeaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(1,12)]]
names(r) <- c("MAT","MAP")
pointsQuararibea <- SpatialPoints(QuararibeaCoords, proj4string = r@crs)
valuesQuararibea <- extract(r,pointsQuararibea)
dfQuararibea <- cbind.data.frame(coordinates(pointsQuararibea),valuesQuararibea)


MATQuararibea= as.numeric(dfQuararibea$MAT)
MATQuararibea= na.omit(MATQuararibea)
hMATQuararibea <- dpik(MATQuararibea)


MAPQuararibea= as.numeric(dfQuararibea$MAP)
MAPQuararibea= na.omit(MAPQuararibea)
hMAPQuararibea=dpik(MAPQuararibea)


x <- cbind(MAPQuararibea,MATQuararibea)
estQuararibea <- bkde2D(x, bandwidth=c(hMAPQuararibea,hMATQuararibea),range.x=list(c(0,5000), c(0,300 )))
image(estQuararibea$x1, estQuararibea$x2, estQuararibea$fhat)




## List of lists of all Microfossils



MicrofossilLibrary1_12=list(estAlisCladeA, estBombacoideae, estEumalvoideae, estGrewieae, estPolygaleae, estAguiaria, estAlchornea, estAmanoa, estAnemia, estAraucaria, estCatostemma, estChrysophyllum, estCremastosperma, estDalechampia, estIriartea, estLudwigia, estMalmea, estMauritia, estMerremia, estMicropholis, estPelliciera, estPhytelephas, estPodocarpus, estPolypodium, estQuararibea, estSapium)


names(MicrofossilLibrary1_12)<- c("AlisCladeA", "Bombacoideae", "Eumalvoideae", "Grewieae", "Polygaleae", "Aguiaria", "Alchornea", "Amanoa", "Anemia", "Araucaria", "Catostemma", "Chrysophyllum", "Cremastosperma", "Dalechampia", "Iriartea", "Ludwigia", "Malmea", "Mauritia", "Merremia", "Micropholis", "Pelliciera", "Phytelephas", "Podocarpus", "Polypodium", "Quararibea", "Sapium")

save(MicrofossilLibrary1_12,file="MicrofossilLibrary1_12.RData")



## List of lists of all Microfossils 500 to 1600 Esmeraldas Fm


MicrofossilLibrary1_12esm=list(estLudwigia,estAlisCladeA,estEumalvoideae,estPhytelephas,estCaesalpinia,estMauritia,estMerremia,estMalmea,estNymphaea,estPolygaleae,estIriartea,estAlchornea,estAmanoa,estSapium,estGrewieae,estJacqueshuberia,estChrysophyllum)

names(MicrofossilLibrary1_12esm)<- c("Ludwigia","AlisCladeA","Eumalvoideae","Phytelephas","Caesalpinia","Mauritia","Merremia","Malmea","Nymphaea","Polygaleae","Iriartea","Alchornea","Amanoa","Sapium","Grewieae","Jacqueshuberia","Chrysophyllum")

save(MicrofossilLibrary1_12esm,file="MicrofossilLibrary1_12esm.RData")



#########################################################################################################
##Macrofossils##
#########################################################################################################

##pteroClade

dfPteroCladeCoords <- read.csv("~/dfPteroClade.csv", sep=",")
pteroCoords <- data.frame(x=dfPteroCladeCoords$x,y=dfPteroCladeCoords$y)
pteroCoords <- na.omit(pteroCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsptero <- SpatialPoints(pteroCoords, proj4string = r@crs)
valuesptero <- extract(r,pointsptero)
dfPteroClade <- cbind.data.frame(coordinates(pointsptero),valuesptero)


PrecDriePtero= as.numeric(dfPteroClade$PrecDrie)
PrecDriePtero= na.omit(PrecDriePtero)
hPPteroClade=dpik(PrecDriePtero)


PrecSeasPtero= as.numeric(dfPteroClade$PrecSeas)
PrecSeasPtero= na.omit(PrecSeasPtero)
hSPteroClade <- dpik(PrecSeasPtero)

xPtero <- cbind(PrecDriePtero,PrecSeasPtero)
estPteroClade <- bkde2D(xPtero, bandwidth=c(hPPteroClade,hSPteroClade),range.x=list(c(-50,1500), c(-50,200)))
image(estPteroClade$x1, estPteroClade$x2, estPteroClade$fhat) 



## Menispermaceae DFA clade new world

dfCissampelosCoords <- read.csv("~/dfCissampelos.csv", sep=",")
CissampelosCoords <- data.frame(x=dfCissampelosCoords$x,y=dfCissampelosCoords$y)
CissampelosCoords <- na.omit(CissampelosCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsCissampelos <- SpatialPoints(CissampelosCoords, proj4string = r@crs)
valuesCissampelos <- extract(r,pointsCissampelos)
dfCissampelos <- cbind.data.frame(coordinates(pointsCissampelos),valuesCissampelos)


PrecDrieCissampelos= as.numeric(dfCissampelos$PrecDrie)
PrecDrieCissampelos= na.omit(PrecDrieCissampelos)
hPCissampelos=dpik(PrecDrieCissampelos)


PrecSeasCissampelos= as.numeric(dfCissampelos$PrecSeas)
PrecSeasCissampelos= na.omit(PrecSeasCissampelos)
hSCissampelos <- dpik(PrecSeasCissampelos)

xCissampelos <- cbind(PrecDrieCissampelos,PrecSeasCissampelos)
estCissampelos <- bkde2D(xCissampelos, bandwidth=c(hPCissampelos,hSCissampelos),range.x=list(c(-50,1500), c(-50,200)))
image(estCissampelos$x1, estCissampelos$x2, estCissampelos$fhat) 


##Passifloroideae

dfPassifloroideaeCoords <- read.csv("~/dfPassifloroideae.csv", sep=",")
PassifloroideaeCoords <- data.frame(x=dfPassifloroideaeCoords$x,y=dfPassifloroideaeCoords$y)
PassifloroideaeCoords <- na.omit(PassifloroideaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsPassifloroideae <- SpatialPoints(PassifloroideaeCoords, proj4string = r@crs)
valuesPassifloroideae <- extract(r,pointsPassifloroideae)
dfPassifloroideae <- cbind.data.frame(coordinates(pointsPassifloroideae),valuesPassifloroideae)


PrecDriePassifloroideae= as.numeric(dfPassifloroideae$PrecDrie)
PrecDriePassifloroideae= na.omit(PrecDriePassifloroideae)
hPPassifloroideae=dpik(PrecDriePassifloroideae)


PrecSeasPassifloroideae= as.numeric(dfPassifloroideae$PrecSeas)
PrecSeasPassifloroideae= na.omit(PrecSeasPassifloroideae)
hSPassifloroideae <- dpik(PrecSeasPassifloroideae)

xPassifloroideae <- cbind(PrecDriePassifloroideae,PrecSeasPassifloroideae)
estPassifloroideae <- bkde2D(xPassifloroideae, bandwidth=c(hPPassifloroideae,hSPassifloroideae),range.x=list(c(-50,1500), c(-50,200)))
image(estPassifloroideae$x1, estPassifloroideae$x2, estPassifloroideae$fhat) 



## Salvinia

dfSalviniaCoords <- read.csv("~/dfSalvinia.csv", sep=",")
SalviniaCoords <- data.frame(x=dfSalviniaCoords$x,y=dfSalviniaCoords$y)
SalviniaCoords <- na.omit(SalviniaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsSalvinia <- SpatialPoints(SalviniaCoords, proj4string = r@crs)
valuesSalvinia <- extract(r,pointsSalvinia)
dfSalvinia <- cbind.data.frame(coordinates(pointsSalvinia),valuesSalvinia)


PrecDrieSalvinia= as.numeric(dfSalvinia$PrecDrie)
PrecDrieSalvinia= na.omit(PrecDrieSalvinia)
hPSalvinia=dpik(PrecDrieSalvinia)


PrecSeasSalvinia= as.numeric(dfSalvinia$PrecSeas)
PrecSeasSalvinia= na.omit(PrecSeasSalvinia)
hSSalvinia <- dpik(PrecSeasSalvinia)

xSalvinia <- cbind(PrecDrieSalvinia,PrecSeasSalvinia)
estSalvinia <- bkde2D(xSalvinia, bandwidth=c(hPSalvinia,hSSalvinia),range.x=list(c(-50,1500), c(-50,200)))
image(estSalvinia$x1, estSalvinia$x2, estSalvinia$fhat) 


## Solanaceae


dfSolanaceae=read.csv("~/dfSolanaceae.csv", sep=",")
SolanaceaeCoords <- data.frame(x=dfSolanaceae$x,y=dfSolanaceae$y)
SolanaceaeCoords <- na.omit(SolanaceaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsSolanaceae <- SpatialPoints(SolanaceaeCoords, proj4string = r@crs)
valuesSolanaceae <- extract(r,pointsSolanaceae)
dfSolanaceae <- cbind.data.frame(coordinates(pointsSolanaceae),valuesSolanaceae)


PrecSeasSolanaceae= as.numeric(dfSolanaceae$PrecSeas)
PrecSeasSolanaceae= na.omit(PrecSeasSolanaceae)
hSSolanaceae <- dpik(PrecSeasSolanaceae)


PrecDrieSolanaceae= as.numeric(dfSolanaceae$PrecDrie)
PrecDrieSolanaceae= na.omit(PrecDrieSolanaceae)
hPSolanaceae=dpik(PrecDrieSolanaceae)


xSolanaceae <- cbind(PrecDrieSolanaceae,PrecSeasSolanaceae)
estSolanaceae <- bkde2D(xSolanaceae, bandwidth=c(hPSolanaceae,hSSolanaceae),range.x=list(c(-100,1500), c(-50,200)))
image(estSolanaceae$x1, estSolanaceae$x2, estSolanaceae$fhat)


## List of list

MacrofossilLibrary15_17=list(estCissampelos, estPassifloroideae, estSalvinia, estSolanaceae,estPteroClade)
names(MacrofossilLibrary15_17) <- c("Menispermaceae","Passifloroideae", "Salvinia", "Solanaceae", "Pterocarpus.Clade")

save(MacrofossilLibrary15_17,file="MacrofossilLibrary15_17.RData")


#########################################################################################################
##Microfossils Library##
#########################################################################################################





## AlisCladeA


dfAlisCladeA=read.csv("~/dfAlisCladeA.csv", sep=",")
AlisCladeACoords <- data.frame(x=dfAlisCladeA$x,y=dfAlisCladeA$y)
AlisCladeACoords <- na.omit(AlisCladeACoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsAlisCladeA <- SpatialPoints(AlisCladeACoords, proj4string = r@crs)
valuesAlisCladeA <- extract(r,pointsAlisCladeA)
dfAlisCladeA <- cbind.data.frame(coordinates(pointsAlisCladeA),valuesAlisCladeA)


PrecSeasAlisCladeA= as.numeric(dfAlisCladeA$PrecSeas)
PrecSeasAlisCladeA= na.omit(PrecSeasAlisCladeA)
hPrecSeasAlisCladeA <- dpik(PrecSeasAlisCladeA)


PrecDrieAlisCladeA= as.numeric(dfAlisCladeA$PrecDrie)
PrecDrieAlisCladeA= na.omit(PrecDrieAlisCladeA)
hPrecDrieAlisCladeA=dpik(PrecDrieAlisCladeA)


x <- cbind(PrecDrieAlisCladeA,PrecSeasAlisCladeA)
estAlisCladeA <- bkde2D(x, bandwidth=c(hPrecDrieAlisCladeA,hPrecSeasAlisCladeA),range.x=list(c(-100,1500), c(-50,200)))
image(estAlisCladeA$x1, estAlisCladeA$x2, estAlisCladeA$fhat)



## Bombacoideae


dfBombacoideae=read.csv("~/dfBombacoideae.csv", sep=",")
BombacoideaeCoords <- data.frame(x=dfBombacoideae$x,y=dfBombacoideae$y)
BombacoideaeCoords <- na.omit(BombacoideaeCoords)



r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsBombacoideae <- SpatialPoints(BombacoideaeCoords, proj4string = r@crs)
valuesBombacoideae <- extract(r,pointsBombacoideae)
dfBombacoideae <- cbind.data.frame(coordinates(pointsBombacoideae),valuesBombacoideae)


PrecSeasBombacoideae= as.numeric(dfBombacoideae$PrecSeas)
PrecSeasBombacoideae= na.omit(PrecSeasBombacoideae)
hPrecSeasBombacoideae <- dpik(PrecSeasBombacoideae)


PrecDrieBombacoideae= as.numeric(dfBombacoideae$PrecDrie)
PrecDrieBombacoideae= na.omit(PrecDrieBombacoideae)
hPrecDrieBombacoideae=dpik(PrecDrieBombacoideae)


x <- cbind(PrecDrieBombacoideae,PrecSeasBombacoideae)
estBombacoideae <- bkde2D(x, bandwidth=c(hPrecDrieBombacoideae,hPrecSeasBombacoideae),range.x=list(c(-100,1500), c(-50,200)))
image(estBombacoideae$x1, estBombacoideae$x2, estBombacoideae$fhat)





## Chrysophyllum


dfChrysophyllum=read.csv("~/dfChrysophyllum.csv", sep=",")
ChrysophyllumCoords <- data.frame(x=dfChrysophyllum$x,y=dfChrysophyllum$y)
ChrysophyllumCoords <- na.omit(ChrysophyllumCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsChrysophyllum <- SpatialPoints(ChrysophyllumCoords, proj4string = r@crs)
valuesChrysophyllum <- extract(r,pointsChrysophyllum)
dfChrysophyllum <- cbind.data.frame(coordinates(pointsChrysophyllum),valuesChrysophyllum)


PrecSeasChrysophyllum= as.numeric(dfChrysophyllum$PrecSeas)
PrecSeasChrysophyllum= na.omit(PrecSeasChrysophyllum)
hPrecSeasChrysophyllum <- dpik(PrecSeasChrysophyllum)


PrecDrieChrysophyllum= as.numeric(dfChrysophyllum$PrecDrie)
PrecDrieChrysophyllum= na.omit(PrecDrieChrysophyllum)
hPrecDrieChrysophyllum=dpik(PrecDrieChrysophyllum)


x <- cbind(PrecDrieChrysophyllum,PrecSeasChrysophyllum)
estChrysophyllum <- bkde2D(x, bandwidth=c(hPrecDrieChrysophyllum,hPrecSeasChrysophyllum),range.x=list(c(-100,1500), c(-50,200)))
image(estChrysophyllum$x1, estChrysophyllum$x2, estChrysophyllum$fhat)


## Eumalvoideae


dfEumalvoideae=read.csv("~/dfEumalvoideae.csv", sep=",")
EumalvoideaeCoords <- data.frame(x=dfEumalvoideae$x,y=dfEumalvoideae$y)
EumalvoideaeCoords <- na.omit(EumalvoideaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsEumalvoideae <- SpatialPoints(EumalvoideaeCoords, proj4string = r@crs)
valuesEumalvoideae <- extract(r,pointsEumalvoideae)
dfEumalvoideae <- cbind.data.frame(coordinates(pointsEumalvoideae),valuesEumalvoideae)


PrecSeasEumalvoideae= as.numeric(dfEumalvoideae$PrecSeas)
PrecSeasEumalvoideae= na.omit(PrecSeasEumalvoideae)
hPrecSeasEumalvoideae <- dpik(PrecSeasEumalvoideae)


PrecDrieEumalvoideae= as.numeric(dfEumalvoideae$PrecDrie)
PrecDrieEumalvoideae= na.omit(PrecDrieEumalvoideae)
hPrecDrieEumalvoideae=dpik(PrecDrieEumalvoideae)


x <- cbind(PrecDrieEumalvoideae,PrecSeasEumalvoideae)
estEumalvoideae <- bkde2D(x, bandwidth=c(hPrecDrieEumalvoideae,hPrecSeasEumalvoideae),range.x=list(c(-100,1500), c(-50,200)))
image(estEumalvoideae$x1, estEumalvoideae$x2, estEumalvoideae$fhat)


## Grewieae


dfGrewieae=read.csv("~/dfGrewieae.csv", sep=",")
GrewieaeCoords <- data.frame(x=dfGrewieae$x,y=dfGrewieae$y)
GrewieaeCoords <- na.omit(GrewieaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsGrewieae <- SpatialPoints(GrewieaeCoords, proj4string = r@crs)
valuesGrewieae <- extract(r,pointsGrewieae)
dfGrewieae <- cbind.data.frame(coordinates(pointsGrewieae),valuesGrewieae)


PrecSeasGrewieae= as.numeric(dfGrewieae$PrecSeas)
PrecSeasGrewieae= na.omit(PrecSeasGrewieae)
hPrecSeasGrewieae <- dpik(PrecSeasGrewieae)


PrecDrieGrewieae= as.numeric(dfGrewieae$PrecDrie)
PrecDrieGrewieae= na.omit(PrecDrieGrewieae)
hPrecDrieGrewieae=dpik(PrecDrieGrewieae)


x <- cbind(PrecDrieGrewieae,PrecSeasGrewieae)
estGrewieae <- bkde2D(x, bandwidth=c(hPrecDrieGrewieae,hPrecSeasGrewieae),range.x=list(c(-100,1500), c(-50,200)))
image(estGrewieae$x1, estGrewieae$x2, estGrewieae$fhat)



## Mauritia


dfMauritia=read.csv("~/dfMauritia.csv", sep=",")
MauritiaCoords <- data.frame(x=dfMauritia$x,y=dfMauritia$y)
MauritiaCoords <- na.omit(MauritiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsMauritia <- SpatialPoints(MauritiaCoords, proj4string = r@crs)
valuesMauritia <- extract(r,pointsMauritia)
dfMauritia <- cbind.data.frame(coordinates(pointsMauritia),valuesMauritia)


PrecSeasMauritia= as.numeric(dfMauritia$PrecSeas)
PrecSeasMauritia= na.omit(PrecSeasMauritia)
hPrecSeasMauritia <- dpik(PrecSeasMauritia)


PrecDrieMauritia= as.numeric(dfMauritia$PrecDrie)
PrecDrieMauritia= na.omit(PrecDrieMauritia)
hPrecDrieMauritia=dpik(PrecDrieMauritia)


x <- cbind(PrecDrieMauritia,PrecSeasMauritia)
estMauritia <- bkde2D(x, bandwidth=c(hPrecDrieMauritia,hPrecSeasMauritia),range.x=list(c(-100,1500), c(-50,200)))
image(estMauritia$x1, estMauritia$x2, estMauritia$fhat)


## Merremia


dfMerremia=read.csv("~/dfMerremia.csv", sep=",")
MerremiaCoords <- data.frame(x=dfMerremia$x,y=dfMerremia$y)
MerremiaCoords <- na.omit(MerremiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsMerremia <- SpatialPoints(MerremiaCoords, proj4string = r@crs)
valuesMerremia <- extract(r,pointsMerremia)
dfMerremia <- cbind.data.frame(coordinates(pointsMerremia),valuesMerremia)


PrecSeasMerremia= as.numeric(dfMerremia$PrecSeas)
PrecSeasMerremia= na.omit(PrecSeasMerremia)
hPrecSeasMerremia <- dpik(PrecSeasMerremia)


PrecDrieMerremia= as.numeric(dfMerremia$PrecDrie)
PrecDrieMerremia= na.omit(PrecDrieMerremia)
hPrecDrieMerremia=dpik(PrecDrieMerremia)


x <- cbind(PrecDrieMerremia,PrecSeasMerremia)
estMerremia <- bkde2D(x, bandwidth=c(hPrecDrieMerremia,hPrecSeasMerremia),range.x=list(c(-100,1500), c(-50,200)))
image(estMerremia$x1, estMerremia$x2, estMerremia$fhat)




## Alchornea


dfAlchornea=read.csv("~/dfAlchornea.csv", sep=",")
AlchorneaCoords <- data.frame(x=dfAlchornea$x,y=dfAlchornea$y)
AlchorneaCoords <- na.omit(AlchorneaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsAlchornea <- SpatialPoints(AlchorneaCoords, proj4string = r@crs)
valuesAlchornea <- extract(r,pointsAlchornea)
dfAlchornea <- cbind.data.frame(coordinates(pointsAlchornea),valuesAlchornea)


PrecSeasAlchornea= as.numeric(dfAlchornea$PrecSeas)
PrecSeasAlchornea= na.omit(PrecSeasAlchornea)
hPrecSeasAlchornea <- dpik(PrecSeasAlchornea)


PrecDrieAlchornea= as.numeric(dfAlchornea$PrecDrie)
PrecDrieAlchornea= na.omit(PrecDrieAlchornea)
hPrecDrieAlchornea=dpik(PrecDrieAlchornea)


x <- cbind(PrecDrieAlchornea,PrecSeasAlchornea)
estAlchornea <- bkde2D(x, bandwidth=c(hPrecDrieAlchornea,hPrecSeasAlchornea),range.x=list(c(-100,1500), c(-50,200)))
image(estAlchornea$x1, estAlchornea$x2, estAlchornea$fhat)





## Amanoa


dfAmanoa=read.csv("~/dfAmanoa.csv", sep=",")
AmanoaCoords <- data.frame(x=dfAmanoa$x,y=dfAmanoa$y)
AmanoaCoords <- na.omit(AmanoaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsAmanoa <- SpatialPoints(AmanoaCoords, proj4string = r@crs)
valuesAmanoa <- extract(r,pointsAmanoa)
dfAmanoa <- cbind.data.frame(coordinates(pointsAmanoa),valuesAmanoa)


PrecSeasAmanoa= as.numeric(dfAmanoa$PrecSeas)
PrecSeasAmanoa= na.omit(PrecSeasAmanoa)
hPrecSeasAmanoa <- dpik(PrecSeasAmanoa)


PrecDrieAmanoa= as.numeric(dfAmanoa$PrecDrie)
PrecDrieAmanoa= na.omit(PrecDrieAmanoa)
hPrecDrieAmanoa=dpik(PrecDrieAmanoa)


x <- cbind(PrecDrieAmanoa,PrecSeasAmanoa)
estAmanoa <- bkde2D(x, bandwidth=c(hPrecDrieAmanoa,hPrecSeasAmanoa),range.x=list(c(-100,1500), c(-50,200)))
image(estAmanoa$x1, estAmanoa$x2, estAmanoa$fhat)



## Polygaleae


dfPolygaleae=read.csv("~/dfPolygaleae.csv", sep=",")
PolygaleaeCoords <- data.frame(x=dfPolygaleae$x,y=dfPolygaleae$y)
PolygaleaeCoords <- na.omit(PolygaleaeCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsPolygaleae <- SpatialPoints(PolygaleaeCoords, proj4string = r@crs)
valuesPolygaleae <- extract(r,pointsPolygaleae)
dfPolygaleae <- cbind.data.frame(coordinates(pointsPolygaleae),valuesPolygaleae)


PrecSeasPolygaleae= as.numeric(dfPolygaleae$PrecSeas)
PrecSeasPolygaleae= na.omit(PrecSeasPolygaleae)
hPrecSeasPolygaleae <- dpik(PrecSeasPolygaleae)


PrecDriePolygaleae= as.numeric(dfPolygaleae$PrecDrie)
PrecDriePolygaleae= na.omit(PrecDriePolygaleae)
hPrecDriePolygaleae=dpik(PrecDriePolygaleae)


x <- cbind(PrecDriePolygaleae,PrecSeasPolygaleae)
estPolygaleae <- bkde2D(x, bandwidth=c(hPrecDriePolygaleae,hPrecSeasPolygaleae),range.x=list(c(-100,1500), c(-50,200)))
image(estPolygaleae$x1, estPolygaleae$x2, estPolygaleae$fhat)






## Malmea


dfMalmea=read.csv("~/dfMalmea.csv", sep=",")
MalmeaCoords <- data.frame(x=dfMalmea$x,y=dfMalmea$y)
MalmeaCoords <- na.omit(MalmeaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsMalmea <- SpatialPoints(MalmeaCoords, proj4string = r@crs)
valuesMalmea <- extract(r,pointsMalmea)
dfMalmea <- cbind.data.frame(coordinates(pointsMalmea),valuesMalmea)


PrecSeasMalmea= as.numeric(dfMalmea$PrecSeas)
PrecSeasMalmea= na.omit(PrecSeasMalmea)
hPrecSeasMalmea <- dpik(PrecSeasMalmea)


PrecDrieMalmea= as.numeric(dfMalmea$PrecDrie)
PrecDrieMalmea= na.omit(PrecDrieMalmea)
hPrecDrieMalmea=dpik(PrecDrieMalmea)


x <- cbind(PrecDrieMalmea,PrecSeasMalmea)
estMalmea <- bkde2D(x, bandwidth=c(hPrecDrieMalmea,hPrecSeasMalmea),range.x=list(c(-100,1500), c(-50,200)))
image(estMalmea$x1, estMalmea$x2, estMalmea$fhat)





## Ludwigia


dfLudwigia=read.csv("~/dfLudwigia.csv", sep=",")
LudwigiaCoords <- data.frame(x=dfLudwigia$x,y=dfLudwigia$y)
LudwigiaCoords <- na.omit(LudwigiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsLudwigia <- SpatialPoints(LudwigiaCoords, proj4string = r@crs)
valuesLudwigia <- extract(r,pointsLudwigia)
dfLudwigia <- cbind.data.frame(coordinates(pointsLudwigia),valuesLudwigia)


PrecSeasLudwigia= as.numeric(dfLudwigia$PrecSeas)
PrecSeasLudwigia= na.omit(PrecSeasLudwigia)
hPrecSeasLudwigia <- dpik(PrecSeasLudwigia)


PrecDrieLudwigia= as.numeric(dfLudwigia$PrecDrie)
PrecDrieLudwigia= na.omit(PrecDrieLudwigia)
hPrecDrieLudwigia=dpik(PrecDrieLudwigia)


x <- cbind(PrecDrieLudwigia,PrecSeasLudwigia)
estLudwigia <- bkde2D(x, bandwidth=c(hPrecDrieLudwigia,hPrecSeasLudwigia),range.x=list(c(-100,1500), c(-50,200)))
image(estLudwigia$x1, estLudwigia$x2, estLudwigia$fhat)


## Sapium


dfSapium=read.csv("~/dfSapium.csv", sep=",")
SapiumCoords <- data.frame(x=dfSapium$x,y=dfSapium$y)
SapiumCoords <- na.omit(SapiumCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsSapium <- SpatialPoints(SapiumCoords, proj4string = r@crs)
valuesSapium <- extract(r,pointsSapium)
dfSapium <- cbind.data.frame(coordinates(pointsSapium),valuesSapium)


PrecSeasSapium= as.numeric(dfSapium$PrecSeas)
PrecSeasSapium= na.omit(PrecSeasSapium)
hPrecSeasSapium <- dpik(PrecSeasSapium)


PrecDrieSapium= as.numeric(dfSapium$PrecDrie)
PrecDrieSapium= na.omit(PrecDrieSapium)
hPrecDrieSapium=dpik(PrecDrieSapium)


x <- cbind(PrecDrieSapium,PrecSeasSapium)
estSapium <- bkde2D(x, bandwidth=c(hPrecDrieSapium,hPrecSeasSapium),range.x=list(c(-100,1500), c(-50,200)))
image(estSapium$x1, estSapium$x2, estSapium$fhat)



## Phytelephas


dfPhytelephas=read.csv("~/dfPhytelephas.csv", sep=",")
PhytelephasCoords <- data.frame(x=dfPhytelephas$x,y=dfPhytelephas$y)
PhytelephasCoords <- na.omit(PhytelephasCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsPhytelephas <- SpatialPoints(PhytelephasCoords, proj4string = r@crs)
valuesPhytelephas <- extract(r,pointsPhytelephas)
dfPhytelephas <- cbind.data.frame(coordinates(pointsPhytelephas),valuesPhytelephas)


PrecSeasPhytelephas= as.numeric(dfPhytelephas$PrecSeas)
PrecSeasPhytelephas= na.omit(PrecSeasPhytelephas)
hPrecSeasPhytelephas <- dpik(PrecSeasPhytelephas)


PrecDriePhytelephas= as.numeric(dfPhytelephas$PrecDrie)
PrecDriePhytelephas= na.omit(PrecDriePhytelephas)
hPrecDriePhytelephas=dpik(PrecDriePhytelephas)


x <- cbind(PrecDriePhytelephas,PrecSeasPhytelephas)
estPhytelephas <- bkde2D(x, bandwidth=c(hPrecDriePhytelephas,hPrecSeasPhytelephas),range.x=list(c(-100,1500), c(-50,200)))
image(estPhytelephas$x1, estPhytelephas$x2, estPhytelephas$fhat)




## Iriartea


dfIriartea=read.csv("~/dfIriartea.csv", sep=",")
IriarteaCoords <- data.frame(x=dfIriartea$x,y=dfIriartea$y)
IriarteaCoords <- na.omit(IriarteaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsIriartea <- SpatialPoints(IriarteaCoords, proj4string = r@crs)
valuesIriartea <- extract(r,pointsIriartea)
dfIriartea <- cbind.data.frame(coordinates(pointsIriartea),valuesIriartea)


PrecSeasIriartea= as.numeric(dfIriartea$PrecSeas)
PrecSeasIriartea= na.omit(PrecSeasIriartea)
hPrecSeasIriartea <- dpik(PrecSeasIriartea)


PrecDrieIriartea= as.numeric(dfIriartea$PrecDrie)
PrecDrieIriartea= na.omit(PrecDrieIriartea)
hPrecDrieIriartea=dpik(PrecDrieIriartea)


x <- cbind(PrecDrieIriartea,PrecSeasIriartea)
estIriartea <- bkde2D(x, bandwidth=c(hPrecDrieIriartea,hPrecSeasIriartea),range.x=list(c(-100,1500), c(-50,200)))
image(estIriartea$x1, estIriartea$x2, estIriartea$fhat)





## Aguiaria


dfAguiaria=read.csv("~/dfAguiaria.csv", sep=",")
AguiariaCoords <- data.frame(x=dfAguiaria$x,y=dfAguiaria$y)
AguiariaCoords <- na.omit(AguiariaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsAguiaria <- SpatialPoints(AguiariaCoords, proj4string = r@crs)
valuesAguiaria <- extract(r,pointsAguiaria)
dfAguiaria <- cbind.data.frame(coordinates(pointsAguiaria),valuesAguiaria)


PrecSeasAguiaria= as.numeric(dfAguiaria$PrecSeas)
PrecSeasAguiaria= na.omit(PrecSeasAguiaria)
hPrecSeasAguiaria <- dpik(PrecSeasAguiaria)


PrecDrieAguiaria= as.numeric(dfAguiaria$PrecDrie)
PrecDrieAguiaria= na.omit(PrecDrieAguiaria)
hPrecDrieAguiaria=dpik(PrecDrieAguiaria)


x <- cbind(PrecDrieAguiaria,PrecSeasAguiaria)
estAguiaria <- bkde2D(x,bandwidth =c(7,7), range.x=list(c(-100,1500), c(-50,200)))
image(estAguiaria$x1, estAguiaria$x2, estAguiaria$fhat)



## Anemia


dfAnemia=read.csv("~/dfAnemia.csv", sep=",")
AnemiaCoords <- data.frame(x=dfAnemia$x,y=dfAnemia$y)
AnemiaCoords <- na.omit(AnemiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsAnemia <- SpatialPoints(AnemiaCoords, proj4string = r@crs)
valuesAnemia <- extract(r,pointsAnemia)
dfAnemia <- cbind.data.frame(coordinates(pointsAnemia),valuesAnemia)


PrecSeasAnemia= as.numeric(dfAnemia$PrecSeas)
PrecSeasAnemia= na.omit(PrecSeasAnemia)
hPrecSeasAnemia <- dpik(PrecSeasAnemia)


PrecDrieAnemia= as.numeric(dfAnemia$PrecDrie)
PrecDrieAnemia= na.omit(PrecDrieAnemia)
hPrecDrieAnemia=dpik(PrecDrieAnemia)


x <- cbind(PrecDrieAnemia,PrecSeasAnemia)
estAnemia <- bkde2D(x, bandwidth=c(hPrecDrieAnemia,hPrecSeasAnemia),range.x=list(c(-100,1500), c(-50,200)))
image(estAnemia$x1, estAnemia$x2, estAnemia$fhat)


## Araucaria


dfAraucaria=read.csv("~/dfAraucaria.csv", sep=",")
AraucariaCoords <- data.frame(x=dfAraucaria$x,y=dfAraucaria$y)
AraucariaCoords <- na.omit(AraucariaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsAraucaria <- SpatialPoints(AraucariaCoords, proj4string = r@crs)
valuesAraucaria <- extract(r,pointsAraucaria)
dfAraucaria <- cbind.data.frame(coordinates(pointsAraucaria),valuesAraucaria)


PrecSeasAraucaria= as.numeric(dfAraucaria$PrecSeas)
PrecSeasAraucaria= na.omit(PrecSeasAraucaria)
hPrecSeasAraucaria <- dpik(PrecSeasAraucaria)


PrecDrieAraucaria= as.numeric(dfAraucaria$PrecDrie)
PrecDrieAraucaria= na.omit(PrecDrieAraucaria)
hPrecDrieAraucaria=dpik(PrecDrieAraucaria)


x <- cbind(PrecDrieAraucaria,PrecSeasAraucaria)
estAraucaria <- bkde2D(x, bandwidth=c(hPrecDrieAraucaria,hPrecSeasAraucaria),range.x=list(c(-100,1500), c(-50,200)))
image(estAraucaria$x1, estAraucaria$x2, estAraucaria$fhat)



## Catostemma


dfCatostemma=read.csv("~/dfCatostemma.csv", sep=",")
CatostemmaCoords <- data.frame(x=dfCatostemma$x,y=dfCatostemma$y)
CatostemmaCoords <- na.omit(CatostemmaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsCatostemma <- SpatialPoints(CatostemmaCoords, proj4string = r@crs)
valuesCatostemma <- extract(r,pointsCatostemma)
dfCatostemma <- cbind.data.frame(coordinates(pointsCatostemma),valuesCatostemma)


PrecSeasCatostemma= as.numeric(dfCatostemma$PrecSeas)
PrecSeasCatostemma= na.omit(PrecSeasCatostemma)
hPrecSeasCatostemma <- dpik(PrecSeasCatostemma)


PrecDrieCatostemma= as.numeric(dfCatostemma$PrecDrie)
PrecDrieCatostemma= na.omit(PrecDrieCatostemma)
hPrecDrieCatostemma=dpik(PrecDrieCatostemma)


x <- cbind(PrecDrieCatostemma,PrecSeasCatostemma)
estCatostemma <- bkde2D(x, bandwidth=c(hPrecDrieCatostemma,hPrecSeasCatostemma),range.x=list(c(-100,1500), c(-50,200)))
image(estCatostemma$x1, estCatostemma$x2, estCatostemma$fhat)



## Cremastosperma


dfCremastosperma=read.csv("~/dfCremastosperma.csv", sep=",")
CremastospermaCoords <- data.frame(x=dfCremastosperma$x,y=dfCremastosperma$y)
CremastospermaCoords <- na.omit(CremastospermaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsCremastosperma <- SpatialPoints(CremastospermaCoords, proj4string = r@crs)
valuesCremastosperma <- extract(r,pointsCremastosperma)
dfCremastosperma <- cbind.data.frame(coordinates(pointsCremastosperma),valuesCremastosperma)


PrecSeasCremastosperma= as.numeric(dfCremastosperma$PrecSeas)
PrecSeasCremastosperma= na.omit(PrecSeasCremastosperma)
hPrecSeasCremastosperma <- dpik(PrecSeasCremastosperma)


PrecDrieCremastosperma= as.numeric(dfCremastosperma$PrecDrie)
PrecDrieCremastosperma= na.omit(PrecDrieCremastosperma)
hPrecDrieCremastosperma=dpik(PrecDrieCremastosperma)


x <- cbind(PrecDrieCremastosperma,PrecSeasCremastosperma)
estCremastosperma <- bkde2D(x, bandwidth=c(hPrecDrieCremastosperma,hPrecSeasCremastosperma),range.x=list(c(-100,1500), c(-50,200)))
image(estCremastosperma$x1, estCremastosperma$x2, estCremastosperma$fhat)




## Dalechampia


dfDalechampia=read.csv("~/dfDalechampia.csv", sep=",")
DalechampiaCoords <- data.frame(x=dfDalechampia$x,y=dfDalechampia$y)
DalechampiaCoords <- na.omit(DalechampiaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsDalechampia <- SpatialPoints(DalechampiaCoords, proj4string = r@crs)
valuesDalechampia <- extract(r,pointsDalechampia)
dfDalechampia <- cbind.data.frame(coordinates(pointsDalechampia),valuesDalechampia)


PrecSeasDalechampia= as.numeric(dfDalechampia$PrecSeas)
PrecSeasDalechampia= na.omit(PrecSeasDalechampia)
hPrecSeasDalechampia <- dpik(PrecSeasDalechampia)


PrecDrieDalechampia= as.numeric(dfDalechampia$PrecDrie)
PrecDrieDalechampia= na.omit(PrecDrieDalechampia)
hPrecDrieDalechampia=dpik(PrecDrieDalechampia)


x <- cbind(PrecDrieDalechampia,PrecSeasDalechampia)
estDalechampia <- bkde2D(x, bandwidth=c(hPrecDrieDalechampia,hPrecSeasDalechampia),range.x=list(c(-100,1500), c(-50,200)))
image(estDalechampia$x1, estDalechampia$x2, estDalechampia$fhat)





## Micropholis


dfMicropholis=read.csv("~/dfMicropholis.csv", sep=",")
MicropholisCoords <- data.frame(x=dfMicropholis$x,y=dfMicropholis$y)
MicropholisCoords <- na.omit(MicropholisCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsMicropholis <- SpatialPoints(MicropholisCoords, proj4string = r@crs)
valuesMicropholis <- extract(r,pointsMicropholis)
dfMicropholis <- cbind.data.frame(coordinates(pointsMicropholis),valuesMicropholis)


PrecSeasMicropholis= as.numeric(dfMicropholis$PrecSeas)
PrecSeasMicropholis= na.omit(PrecSeasMicropholis)
hPrecSeasMicropholis <- dpik(PrecSeasMicropholis)


PrecDrieMicropholis= as.numeric(dfMicropholis$PrecDrie)
PrecDrieMicropholis= na.omit(PrecDrieMicropholis)
hPrecDrieMicropholis=dpik(PrecDrieMicropholis)


x <- cbind(PrecDrieMicropholis,PrecSeasMicropholis)
estMicropholis <- bkde2D(x, bandwidth=c(hPrecDrieMicropholis,hPrecSeasMicropholis),range.x=list(c(-100,1500), c(-50,200)))
image(estMicropholis$x1, estMicropholis$x2, estMicropholis$fhat)




## Pelliciera


dfPelliciera=read.csv("~/dfPelliciera.csv", sep=",")
PellicieraCoords <- data.frame(x=dfPelliciera$x,y=dfPelliciera$y)
PellicieraCoords <- na.omit(PellicieraCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsPelliciera <- SpatialPoints(PellicieraCoords, proj4string = r@crs)
valuesPelliciera <- extract(r,pointsPelliciera)
dfPelliciera <- cbind.data.frame(coordinates(pointsPelliciera),valuesPelliciera)


PrecSeasPelliciera= as.numeric(dfPelliciera$PrecSeas)
PrecSeasPelliciera= na.omit(PrecSeasPelliciera)
hPrecSeasPelliciera <- dpik(PrecSeasPelliciera)


PrecDriePelliciera= as.numeric(dfPelliciera$PrecDrie)
PrecDriePelliciera= na.omit(PrecDriePelliciera)
hPrecDriePelliciera=dpik(PrecDriePelliciera)


x <- cbind(PrecDriePelliciera,PrecSeasPelliciera)
estPelliciera <- bkde2D(x, bandwidth=c(hPrecDriePelliciera,hPrecSeasPelliciera),range.x=list(c(-100,1500), c(-50,200)))
image(estPelliciera$x1, estPelliciera$x2, estPelliciera$fhat)




## Podocarpus


dfPodocarpus=read.csv("~/dfPodocarpus.csv", sep=",")
PodocarpusCoords <- data.frame(x=dfPodocarpus$x,y=dfPodocarpus$y)
PodocarpusCoords <- na.omit(PodocarpusCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsPodocarpus <- SpatialPoints(PodocarpusCoords, proj4string = r@crs)
valuesPodocarpus <- extract(r,pointsPodocarpus)
dfPodocarpus <- cbind.data.frame(coordinates(pointsPodocarpus),valuesPodocarpus)


PrecSeasPodocarpus= as.numeric(dfPodocarpus$PrecSeas)
PrecSeasPodocarpus= na.omit(PrecSeasPodocarpus)
hPrecSeasPodocarpus <- dpik(PrecSeasPodocarpus)


PrecDriePodocarpus= as.numeric(dfPodocarpus$PrecDrie)
PrecDriePodocarpus= na.omit(PrecDriePodocarpus)
hPrecDriePodocarpus=dpik(PrecDriePodocarpus)


x <- cbind(PrecDriePodocarpus,PrecSeasPodocarpus)
estPodocarpus <- bkde2D(x, bandwidth=c(hPrecDriePodocarpus,hPrecSeasPodocarpus),range.x=list(c(-100,1500), c(-50,200)))
image(estPodocarpus$x1, estPodocarpus$x2, estPodocarpus$fhat)





## Polypodium


dfPolypodium=read.csv("~/dfPolypodium.csv", sep=",")
PolypodiumCoords <- data.frame(x=dfPolypodium$x,y=dfPolypodium$y)
PolypodiumCoords <- na.omit(PolypodiumCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsPolypodium <- SpatialPoints(PolypodiumCoords, proj4string = r@crs)
valuesPolypodium <- extract(r,pointsPolypodium)
dfPolypodium <- cbind.data.frame(coordinates(pointsPolypodium),valuesPolypodium)


PrecSeasPolypodium= as.numeric(dfPolypodium$PrecSeas)
PrecSeasPolypodium= na.omit(PrecSeasPolypodium)
hPrecSeasPolypodium <- dpik(PrecSeasPolypodium)


PrecDriePolypodium= as.numeric(dfPolypodium$PrecDrie)
PrecDriePolypodium= na.omit(PrecDriePolypodium)
hPrecDriePolypodium=dpik(PrecDriePolypodium)


x <- cbind(PrecDriePolypodium,PrecSeasPolypodium)
estPolypodium <- bkde2D(x, bandwidth=c(hPrecDriePolypodium,hPrecSeasPolypodium),range.x=list(c(-100,1500), c(-50,200)))
image(estPolypodium$x1, estPolypodium$x2, estPolypodium$fhat)






## Quararibea


dfQuararibea=read.csv("~/dfQuararibea.csv", sep=",")
QuararibeaCoords <- data.frame(x=dfQuararibea$x,y=dfQuararibea$y)
QuararibeaCoords <- na.omit(QuararibeaCoords)


r <- getData("worldclim",var="bio",res=10)
r <- r[[c(15,17)]]
names(r) <- c("PrecSeas","PrecDrie")
pointsQuararibea <- SpatialPoints(QuararibeaCoords, proj4string = r@crs)
valuesQuararibea <- extract(r,pointsQuararibea)
dfQuararibea <- cbind.data.frame(coordinates(pointsQuararibea),valuesQuararibea)


PrecSeasQuararibea= as.numeric(dfQuararibea$PrecSeas)
PrecSeasQuararibea= na.omit(PrecSeasQuararibea)
hPrecSeasQuararibea <- dpik(PrecSeasQuararibea)


PrecDrieQuararibea= as.numeric(dfQuararibea$PrecDrie)
PrecDrieQuararibea= na.omit(PrecDrieQuararibea)
hPrecDrieQuararibea=dpik(PrecDrieQuararibea)


x <- cbind(PrecDrieQuararibea,PrecSeasQuararibea)
estQuararibea <- bkde2D(x, bandwidth=c(hPrecDrieQuararibea,hPrecSeasQuararibea),range.x=list(c(-100,1500), c(-50,200)))
image(estQuararibea$x1, estQuararibea$x2, estQuararibea$fhat)


#############################################################################################

MicrofossilLibrary15_17=list(estAlisCladeA, estBombacoideae, estEumalvoideae, estGrewieae, estPolygaleae, estAguiaria, estAlchornea, estAmanoa, estAnemia, estAraucaria, estCatostemma, estChrysophyllum, estCremastosperma, estDalechampia, estIriartea, estLudwigia, estMalmea, estMauritia, estMerremia, estMicropholis, estPelliciera, estPhytelephas, estPodocarpus, estPolypodium, estQuararibea, estSapium)


names(MicrofossilLibrary15_17)<- c("AlisCladeA", "Bombacoideae", "Eumalvoideae", "Grewieae", "Polygaleae", "Aguiaria", "Alchornea", "Amanoa", "Anemia", "Araucaria", "Catostemma", "Chrysophyllum", "Cremastosperma", "Dalechampia", "Iriartea", "Ludwigia", "Malmea", "Mauritia", "Merremia", "Micropholis", "Pelliciera", "Phytelephas", "Podocarpus", "Polypodium", "Quararibea", "Sapium")

save(MicrofossilLibrary15_17,file="MicrofossilLibrary15_17.RData")

#########################################################################################################
#########################################################################################################
            ##### COEXISTENCE ######
#########################################################################################################
#########################################################################################################


##################################################################
#MICROFOSSIL COEXISTENCE BIO1 and BIO12 ##
##################################################################



load(file="ModernLibraries.RData")
ls()

#jet.colors is the color pallette


pdf("pdfs MacrofossilLibrary1_12.pdf")
par(mfrow=c(3,3))
for(i in 1:length(MacrofossilLibrary1_12)){
  image(MacrofossilLibrary1_12[[i]][[1]],MacrofossilLibrary1_12[[i]][[2]],MacrofossilLibrary1_12[[i]][[3]],
        xlab="MAP (mm)",ylab="MAT (ºC)",
        col=jet.colors,main=names(MacrofossilLibrary1_12)[i])
}
dev.off()


pdf("pdfs MicrofossilLibrary1_12.pdf")
par(mfrow=c(3,3))
for(i in 1:length(MicrofossilLibrary1_12)){
  image(MicrofossilLibrary1_12[[i]][[1]],MicrofossilLibrary1_12[[i]][[2]],MicrofossilLibrary1_12[[i]][[3]],
        xlab="MAP (mm)",ylab="MAT (ºC)",
        col=jet.colors,main=names(MicrofossilLibrary1_12)[i])
}
dev.off()



## uploading pollen counts

fossil.sp2
dim(fossil.sp2)
length(MicrofossilLibrary1_12)

fossil.sp2=fossil.sp2[,c(2:27)]
row.names(fossil.sp2)=fossil.sp2$Sample

fossil.sp2[is.na(fossil.sp2)] <- 0

#fossil.sp contains the fossil abundances of pollen taxa that are present in both fossil and modern samples. Make a summary of sampling effort and number of taxa in each sample

colnames(fossil.sp2)
dim(fossil.sp2)

fossil.summary<-data.frame(matrix(ncol=2,c(apply(ifelse(fossil.sp2==0,0,1),1,sum),
                                           apply(fossil.sp2,1,sum)),dimnames=list(rownames(fossil.sp2),c("S","pollen count"))))


#fossil estimates based on pollen

colnames(fossil.sp2)
fossil.estimat.pa2<-estimate(fossil.sp2,MicrofossilLibrary1_12,quant=0.95,plot=F, ci=c(0.25,0.75))


class(fossil.estimat.pa2)
length(fossil.estimat.pa2)

#Extract the matrix of pollen based estimates

fossil.estimat.pa2.95<-fossil.estimat.pa2[[1]]


#Mixture of estimates based on pollen 

micro.prec<-density(fossil.estimat.pa2.95[,1],bw=250,from=-500,to=5000)
micro.temp<-density(fossil.estimat.pa2.95[,5],bw=25,from=-50,to=500)

plot(micro.prec)
plot(micro.temp)


#modal pollen-based prec estimate
micro.prec$x[which(micro.prec$y==max(micro.prec$y))]



micro.temp$x[which(micro.temp$y==max(micro.temp$y))]



#Q1, Q2 and median for pollen-based elevation estimates
approx(cumsum(micro.prec$y*(micro.prec$x[2]-
                              micro.prec$x[1])),micro.prec$x,xout=c(0.25,0.5,0.75))$y



approx(cumsum(micro.temp$y*(micro.temp$x[2]-
                              micro.temp$x[1])),micro.temp$x,xout=c(0.25,0.5,0.75))$y







##################################################################
#MACROFOSSIL COEXISTENCE BIO1 and BIO12 ##
##################################################################

macro1<-MacrofossilLibrary1_12[[1]][[3]]/5+MacrofossilLibrary1_12[[2]][[3]]/5+
  MacrofossilLibrary1_12[[3]][[3]]/5+MacrofossilLibrary1_12[[4]][[3]]/5+
  MacrofossilLibrary1_12[[5]][[3]]/5

#estimates made by just mixing the probability density matrices need to be in a list of length three that also contains the x and y axes of the bidimensional pdf. x and y axes can be extracted from any of the modern pdfs

macro<-list(MacrofossilLibrary1_12[[1]][[1]],MacrofossilLibrary1_12[[1]][[2]],macro1)



#funtion "estimate1" extracts specific apparts of the bidimensional pdf. Arguments: 'x' and 'y' are the enviroenmntal axes; 'z.pdf' matrix of densities; quant, loer tail of probability to be ignored


macro.estimate.temp<-estimate1(macro[[2]],macro[[1]],macro[[3]],quant=0.75)

macro.estimate.prec<-estimate1(macro[[1]],macro[[2]],macro[[3]],quant=0.75)



#deconvolve the individual signals of multivariate estimates 
pdf.macro.temp<-density(macro.estimate.temp[,3],bw=25,from=-50,to=500)

pdf.macro.prec<-density(macro.estimate.prec[,2],bw=250,from=-500,to=5000)



#modal macrofossil-based precipitation estimation
mode.macro.prec<-pdf.macro.prec$x[which(
  pdf.macro.prec$y==max(pdf.macro.prec$y))]



mode.macro.temp<-pdf.macro.temp$x[which(
  pdf.macro.temp$y==max(pdf.macro.temp$y))]



#Q1, median, and Q2 for macrofossil-based prec and temp estimation
median.macro.prec<-approx(cumsum(pdf.macro.prec$y*(
  pdf.macro.prec$x[2]-pdf.macro.prec$x[1])),
  pdf.macro.prec$x,xout=c(0.25,0.5,0.75))$y


median.macro.temp<-approx(cumsum(pdf.macro.temp$y*(
  pdf.macro.temp$x[2]-pdf.macro.temp$x[1])),
  pdf.macro.temp$x,xout=c(0.25,0.5,0.75))$y



#mode precip and temp
mode.macro.prec<-pdf.macro.prec$x[which(
  pdf.macro.prec$y==max(pdf.macro.prec$y))]


mode.macro.temp<-pdf.macro.temp$x[which(
  pdf.macro.temp$y==max(pdf.macro.temp$y))]



##################################################################
#MIXTURE OF POLLEN- AND MACROFOSSIL-BASED ESTIMATES BIO1 AND BIO12
##################################################################
#the function 'mixture' produces estimates mixing the univariate pdf derived from each group of fossils. Arguments: 'pdf1' and 'pdf2' are the pdfs to mix
#lambda, proportion (weight) of pdf1 in the mixture; 'quant' is the interquantile range to display


par(mfrow=c(1,2))

p.prec<-mixture(pdf.macro.prec,micro.prec,
                main="MAP",ylim=c(0,5000))
par(new=T)
plot(p.prec[[2]],col="blue",xlab="",ylab="",main="",t="l",axes=F)
axis(4,col="blue")


p.temp<-mixture(pdf.macro.temp,micro.temp,
                main="MAT",ylim=c(0,300))
par(new=T)
plot(p.temp[[2]],col="blue",xlab="",ylab="",main="",t="l",axes=F)
axis(4,col="blue")



#make the mixture with the selected lambda; each object contains the univariate pdf that describe the most likely estimates

prec<-data.frame(cbind(micro.prec$x,
                       0.7*pdf.macro.prec$y+0.5*micro.prec$y))
colnames(prec)<-c("x","density")
prec$P<-cumsum((prec[2,1]-prec[1,1])*prec[,2])
head(prec)
tail(prec)

temp<-data.frame(cbind(micro.temp$x,
                       0.5*pdf.macro.temp$y+0.5*micro.temp$y))
colnames(temp)<-c("x","density")
temp$P<-cumsum((temp[2,1]-temp[1,1])*temp[,2])
head(temp)
tail(temp)


par(mfrow=c(1,2))
plot(prec[,1:2],t="l",xlab="Precipitation")
plot(temp[,1:2],t="l",xlab="Temperature")


approx(prec$P,prec$x,xout=c(0.25,0.5,0.75))



approx(temp$P,temp$x,xout=c(0.25,0.5,0.75))


###########################################################################################################
      ### Coexistence BIO15 and BIO17 ###
###########################################################################################################
load(file="ModernLibraries.RData")
ls()
load(file=jet.colors)
#modern.lib and wood1 are lists, each conating the probabilit?y density functions that describe the distribution of taxa as a functions of the environmental gradients produced by elevation and PrecDrieipitation. These two lists constitute the reference material for mixing distributions based on the distribution of the different taxa in the fossil record

#jet.colors is the color pallette
#plot modern distribution of vegetation and pollen


pdf("pdfs MacrofossilLibrary15_17.pdf")
par(mfrow=c(3,3))
for(i in 1:length(MacrofossilLibrary15_17)){
  image(MacrofossilLibrary15_17[[i]][[1]],MacrofossilLibrary15_17[[i]][[2]],MacrofossilLibrary15_17[[i]][[3]],
        xlab="Prec. Driest Quarter",ylab="Prec. Seasonality",
        col=jet.colors,main=names(MacrofossilLibrary15_17)[i])
}
dev.off()


pdf("pdfs MicrofossilLibrary15_17.pdf")
par(mfrow=c(3,3))
for(i in 1:length(MicrofossilLibrary15_17)){
  image(MicrofossilLibrary15_17[[i]][[1]],MicrofossilLibrary15_17[[i]][[2]],MicrofossilLibrary15_17[[i]][[3]],
        xlab="Prec. Driest Quarter",ylab="Prec. Seasonality",
        col=jet.colors,main=names(MicrofossilLibrary15_17)[i])
}
dev.off()





## uploading pollen counts

##load(fossil.sp2)
dim(fossil.sp2)
length(MicrofossilLibrary15_17)

fossil.sp2=fossil.sp2[,c(2:27)]
row.names(fossil.sp2)=fossil.sp2$Sample

fossil.sp2[is.na(fossil.sp2)] <- 0

#fossil.sp contains the fossil abundances of pollen taxa that are present in both fossil and modern samples. Make a summary of sampling effort and number of taxa in each sample

fossil.summary<-data.frame(matrix(ncol=2,c(apply(ifelse(fossil.sp2==0,0,1),1,sum),
                                           apply(fossil.sp2,1,sum)),dimnames=list(rownames(fossil.sp2),c("S","pollen count"))))


#fossil estimates based on pollen

colnames(fossil.sp2)
fossil.estimat.pa2<-estimate(fossil.sp2,MicrofossilLibrary15_17,quant=0.95,plot=F, ci=c(0.25,0.75))


class(fossil.estimat.pa2)
length(fossil.estimat.pa2)

#Extract the matrix of pollen based estimates

fossil.estimat.pa2.95<-fossil.estimat.pa2[[1]]


#Mixture of estimates based on pollen 

micro.PrecDrie<-density(fossil.estimat.pa2.95[,1],bw=25,from=-50,to=1000)
micro.Seasonality<-density(fossil.estimat.pa2.95[,5],bw=25,from=-25,to=150)

plot(micro.PrecDrie)
plot(micro.Seasonality)


#modal pollen-based PrecDrieipitation estimate
micro.PrecDrie$x[which(micro.PrecDrie$y==max(micro.PrecDrie$y))]



micro.Seasonality$x[which(micro.Seasonality$y==max(micro.Seasonality$y))]



#Q1, Q2 and median for pollen-based elevation estimates
approx(cumsum(micro.PrecDrie$y*(micro.PrecDrie$x[2]-
                                  micro.PrecDrie$x[1])),micro.PrecDrie$x,xout=c(0.25,0.5,0.75))$y



approx(cumsum(micro.Seasonality$y*(micro.Seasonality$x[2]-
                                     micro.Seasonality$x[1])),micro.Seasonality$x,xout=c(0.25,0.5,0.75))$y





##################################################################
#MACROFOSSIL-BASED ESTIMATES
##################################################################

macro1<-MacrofossilLibrary15_17[[1]][[3]]/5+MacrofossilLibrary15_17[[2]][[3]]/5+
  MacrofossilLibrary15_17[[3]][[3]]/5+MacrofossilLibrary15_17[[4]][[3]]/5+
  MacrofossilLibrary15_17[[5]][[3]]/5

#estimates made by just mixing the probability density matrices need to be in a list of length three that also contains the x and y axes of the bidimensional pdf. x and y axes can be extracted from any of the modern pdfs

macro<-list(MacrofossilLibrary15_17[[1]][[1]],MacrofossilLibrary15_17[[1]][[2]],macro1)



#funtion "estimate1" extracts specific apparts of the bidimensional pdf. Arguments: 'x' and 'y' are the enviroenmntal axes; 'z.pdf' matrix of densities; quant, loer tail of probability to be ignored


macro.estimate.Seasonality<-estimate1(macro[[2]],macro[[1]],macro[[3]],quant=0.75)

macro.estimate.PrecDrie<-estimate1(macro[[1]],macro[[2]],macro[[3]],quant=0.75)



#deconvolve the individual signals of multivariate estimates 
pdf.macro.Seasonality<-density(macro.estimate.Seasonality[,3],bw=25,from=-25,to=150)

pdf.macro.PrecDrie<-density(macro.estimate.PrecDrie[,2],bw=25,from=-50,to=1000)


plot(pdf.macro.PrecDrie)
plot(pdf.macro.Seasonality)

# error: micro.Seasonality<-density(fossil.estimat.pa2.95[,5],bw=25,from=-50,to=500)


#modal macrofossil-based PrecDrieipitation estimation
mode.macro.PrecDrie<-pdf.macro.PrecDrie$x[which(
  pdf.macro.PrecDrie$y==max(pdf.macro.PrecDrie$y))]

## [1] 93.83562

mode.macro.Seasonality<-pdf.macro.Seasonality$x[which(
  pdf.macro.Seasonality$y==max(pdf.macro.Seasonality$y))]
## [1] 66.7319


#Q1, median, and Q2 for macrofossil-based PrecDrie and Seasonality estimation
median.macro.PrecDrie<-approx(cumsum(pdf.macro.PrecDrie$y*(
  pdf.macro.PrecDrie$x[2]-pdf.macro.PrecDrie$x[1])),
  pdf.macro.PrecDrie$x,xout=c(0.25,0.5,0.75))$y
##[1] 37.86505  82.53034 120.66234

median.macro.Seasonality<-approx(cumsum(pdf.macro.Seasonality$y*(
  pdf.macro.Seasonality$x[2]-pdf.macro.Seasonality$x[1])),
  pdf.macro.Seasonality$x,xout=c(0.25,0.5,0.75))$y
## [1] 48.99778 67.34684 86.16132


#mode PrecDrieip and Seasonality

mode.macro.PrecDrie<-pdf.macro.PrecDrie$x[which(
  pdf.macro.PrecDrie$y==max(pdf.macro.PrecDrie$y))]

##[1] 93.83562

mode.macro.Seasonality<-pdf.macro.Seasonality$x[which(
  pdf.macro.Seasonality$y==max(pdf.macro.Seasonality$y))]
##[1] 66.7319


##################################################################
#MIXTURE OF POLLEN- AND MACROFOSSIL-BASED ESTIMATES
##################################################################
#the function 'mixture' produces estimates mixing the univariate pdf derived from each group of fossils. Arguments: 'pdf1' and 'pdf2' are the pdfs to mix
#lambda, proportion (weight) of pdf1 in the mixture; 'quant' is the interquantile range to display



par(mfrow=c(1,2))

p.PrecDrie<-mixture(pdf.macro.PrecDrie,micro.PrecDrie,
                    main="Prec. Driest Quarter",ylim=c(-50,400))
par(new=T)
plot(p.PrecDrie[[2]],col="blue",xlab="",ylab="",main="",t="l",axes=F)
axis(4,col="blue")


p.Seasonality<-mixture(pdf.macro.Seasonality,micro.Seasonality,
                       main="Prec. Seasonality",ylim=c(0,100))
par(new=T)
plot(p.Seasonality[[2]],col="blue",xlab="",ylab="",main="",t="l",axes=F)
axis(4,col="blue")



#make the mixture with the selected lambda; each object contains the univariate pdf that describe the most likely estimates

PrecDrie<-data.frame(cbind(micro.PrecDrie$x,
                           0.53*pdf.macro.PrecDrie$y+(1-0.52)*micro.PrecDrie$y))
colnames(PrecDrie)<-c("x","density")
PrecDrie$P<-cumsum((PrecDrie[2,1]-PrecDrie[1,1])*PrecDrie[,2])
head(PrecDrie)
tail(PrecDrie)

Seasonality<-data.frame(cbind(micro.Seasonality$x,
                              0.69*pdf.macro.Seasonality$y+(1-0.68)*micro.Seasonality$y))
colnames(Seasonality)<-c("x","density")
Seasonality$P<-cumsum((Seasonality[2,1]-Seasonality[1,1])*Seasonality[,2])
head(Seasonality)
tail(Seasonality)



plot(PrecDrie[,1:2],t="l",xlab="Precipitation Driest Q.",col="blue",xlim=c(-50,500))
plot(Seasonality[,1:2],t="l",xlab="Seasonality")

install.packages("plotly")
library(plotly)
plot_ly(x = ~PrecDrie[,1], y = ~PrecDrie[,2], type='scatter',mode='lines',names='Fair cut',fill = 'tozeroy') %>%
  layout(xaxis = list(range=c(-100,400)))

plot_ly(x = ~Seasonality[,1], y = ~Seasonality[,2], type='scatter',mode='lines',names='Fair cut',fill = 'tozeroy') %>%
  layout(xaxis = list(range=c(0,100)))


approx(PrecDrie$P,PrecDrie$x,xout=c(0.25,0.5,0.75))



approx(Seasonality$P,Seasonality$x,xout=c(0.25,0.5,0.75))





